<?php
/**
 * Controlador para métodos de un aplicante.
 * User: Henry Vivanco <hvvivanco@rutatec.com>
 * Date: 23/1/2019
 * Time: 12:16
 */

namespace App\Http\Controllers;


use App\Repositories\ApplicantGuardianStudentRepository;
use App\Repositories\ApplicantStudentRepository;
use App\Repositories\EmployeeRepository;
use App\Repositories\UserRepository;
use Illuminate\Http\Request;

class ApplicantStudentController extends Controller
{
    protected $applicantStudent;
    protected $user;
    protected $applicantGuardianStudent;

    public function __construct(ApplicantStudentRepository $applicantStudent, UserRepository $user, ApplicantGuardianStudentRepository $applicantGuardianStudent)
    {
        $this->applicantStudent = $applicantStudent;
        $this->user = $user;
        $this->applicantGuardianStudent = $applicantGuardianStudent;
    }

    /**
     * Método para obtener lista aplicantes en un rango de fechas
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-24
     * @return array $applicants
     */
    public function getApplicantsStudents(Request $request){

        $data = $request->all();
        $applicants = $this->applicantStudent->getApplicants($data);
        return response()->json($applicants);

    }

    /**
     * Método para guardar estado si el estudiante applicante visitó
     * el colegio.
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-24
     * @return success
     */
    public function saveVisitedSchoolStd(Request $request){

        $data = $request->all();
        $this->applicantStudent->saveVisitedSchoolStd($data);
        return response()->json(['success' => 'true', 'message' => 'Se ha registrado el estado'], 200);

    }

    /**
     * Método para guardar estado si el estudiante applicante es apto
     * para el proceso de admisiones
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-24
     * @return success
     */
    public function saveProceedStudent(Request $request){

        $data = $request->all();
        $this->applicantStudent->saveProceedStudent($data);
        return response()->json(['success' => 'true', 'message' => 'Se ha registrado el estado'], 200);

    }

    /**
     * Método para guardar bandera 1 para el proceso de admisiones
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-24
     * @return success
     */
    public function saveFlagOne(Request $request){

        $data = $request->all();
        $this->applicantStudent->saveFlagOne($data);
        return response()->json(['success' => 'true', 'message' => 'Se ha registrado el estado'], 200);

    }

    /**
     * Método para guardar bandera 2 para el proceso de admisiones
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-24
     * @return success
     */
    public function saveFlagTwo(Request $request){

        $data = $request->all();
        $this->applicantStudent->saveFlagTwo($data);
        return response()->json(['success' => 'true', 'message' => 'Se ha registrado el estado'], 200);

    }

    /**
     * Método para guardar bandera 3 para el proceso de admisiones
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-24
     * @return success
     */
    public function saveFlagThree(Request $request){

        $data = $request->all();
        $this->applicantStudent->saveFlagThree($data);
        return response()->json(['success' => 'true', 'message' => 'Se ha registrado el estado'], 200);

    }

    /**
     * Método para obtener los docentes asignados a una sección
     * por año lectivo
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-28
     * @return json $employeeSection
     */
    public function getEmployeeSection(Request $request){

        $data = $request->all();
        $employeeSection = $this->user->getEmployeeSection($data);
        return response()->json($employeeSection);

    }

    /**
     * Método para guardar la observacion para el proceso de admisiones
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-30
     * @return success
     */
    public function saveObservation(Request $request){

        $data = $request->all();
        $this->applicantStudent->saveObservation($data);
        return response()->json(['success' => 'true', 'message' => 'Se ha registrado el estado'], 200);

    }

    /**
     * Método para obtener datos de la solicitud de un estudiante
     * aplicante por serial de aplicante
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-24
     * @return array $applicants
     */
    public function getApplicant(Request $request){

        $data = $request->all();
        $applicants = $this->applicantStudent->getApplicant($data);
        $fatherStudent = $this->applicantGuardianStudent->getGuardianStudent($applicants->serial_ast,'FATHER');
        $applicants['father'] = $fatherStudent;
        $motherStudent = $this->applicantGuardianStudent->getGuardianStudent($applicants->serial_ast,'MOTHER');
        $applicants['mother'] = $motherStudent;
        return response()->json($applicants);

    }

    /**
     * Método para obtener todos los aplicantes de todas
     * las secciones por año lectivo
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-30
     * @return json $employeeSection
     */
    public function getAllSections(Request $request){

        $data = $request->all();
        $employeeSection = $this->user->getAllSections($data);
        $getApplicants = $this->applicantStudent->getAllApplicantBySection($employeeSection,$data);
        return response()->json($getApplicants);

    }

    /**
     * Método para obtener todos los aplicantes de todos
     * los niveles por seccion y año lectivo
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-30
     * @return $employeeSection
     */
    public function getAllLevels(Request $request){

        $data = $request->all();
        $levels = $this->user->getAllLevels($data);
        $getApplicants = $this->applicantStudent->getAllApplicantByLevel($levels,$data);
        return response()->json($getApplicants);

    }

}