<?php

namespace App\Http\Controllers;

use App\Repositories\AttendanceRepository;
use App\Repositories\PeriodRepository;
use App\Repositories\AttendanceLogAtlRepository;
use App\Repositories\CourseRepository;
use App\Repositories\OptionalSubjectRepository;
use App\Repositories\ScheduleRepository;
use App\Repositories\DateDayConfigurationRepository;
use Laravel\Lumen\Routing\Controller as BaseController;
use Illuminate\Http\Request;

class AttendanceController extends BaseController {

    /**
     * @var \Tymon\JWTAuth\JWTAuth
     */
    protected $attendance;
    protected $course;
    protected $scheduele;
    protected $dateDayConfiguration;
    protected $attendanceLogAtlRepository;
    protected $optionalSubject;

    public function __construct(OptionalSubjectRepository $optionalSubject = null, CourseRepository $course, AttendanceRepository $attendance, ScheduleRepository $scheduele, DateDayConfigurationRepository $dateDayConfiguration, AttendanceLogAtlRepository $attendanceLogAtlRepository) {
        $this->optionalSubject = $optionalSubject;
        $this->course = $course;
        $this->attendance = $attendance;
        $this->scheduele = $scheduele;
        $this->dateDayConfiguration = $dateDayConfiguration;
        $this->attendanceLogAtlRepository = $attendanceLogAtlRepository;
    }

    /**
     * Método que devuelve el la lista de estudiantes y si tienen registro de asistencia
     * @since   2017-08-03
     * @author  Fernando Salas <rfsalas@rutatec.com>
     *
     * @param   array $request
     * @return  object $course
     * 
     * @edit    2017-08-03<br />
     *          Fernando Salas <rfsalas@rutatec.com><br />
     *          Creación del método<br/>
     *          #edit1
     */
    public function postListAttendanceStudents(Request $request) {
        try {
            $this->validate($request, [
                'type_subject' => 'required',
                'date' => 'required',
                'serial_crs' => 'required',
                'serial_sbc' => 'required',
                'serial_osb' => 'required',
                'serial_scd' => 'required',
                'serial_crs' => 'required'
            ]);
            $schedule = $this->scheduele->findById($request->input('serial_scd'));
            $dateDayConfiguration = $this->dateDayConfiguration->getDateDayConfiguration($request->input('date'));
            if ($request->input('type_subject') == 'mandatory') {
                //obtengo los estudiantes del curso
                $students = $this->course->getStudents($request->input('serial_crs'));
                foreach ($students as $student) {
                    $student->serial_scd = $schedule->serial_scd;
                    $student->number_subjects = $this->getScheduleBySerialStdSerialScd($student->serial_std, $schedule->serial_scd, $dateDayConfiguration->date_ddc, $schedule->serial_crs, $dateDayConfiguration->day_ddc, $dateDayConfiguration->serial_scy,$schedule->serial_scd);
                    $student->attendance = $this->attendance->getAttendanceStudentSubject($student->serial_std, $request->input('serial_scd'), $request->input('serial_sbc'), null, $request->input('date'));
                }
            } else {
                //obtengo los estudiantes de la materia optativa
                $students = $this->optionalSubject->getStudents($request->input('serial_osb'), $request->input('date'), $schedule->serial_cdt, $dateDayConfiguration->day_ddc);
                //dd($students);
                foreach ($students as $student) {
                    $student->number_subjects = $this->getScheduleBySerialStdSerialScd($student->serial_std, $schedule->serial_cdt, $dateDayConfiguration->date_ddc, $schedule->serial_crs, $dateDayConfiguration->day_ddc, $dateDayConfiguration->serial_scy,$schedule->serial_scd);
                    $student->attendance = $this->attendance->getAttendanceStudentSubject($student->serial_std, $student->serial_scd, null, $student->serial_lop, $request->input('date'));
                }
            }
            $this->attendanceLogAtlRepository->save($request->input('serial_usr'), $request->input('serial_scd'), $request->input('serial_sbc'), $request->input('serial_osb'), $request->input('date'));

            return response()->json($students);
        } catch (\Mockery\Exception $ex) {
            echo $ex->getLine();
            return response()->json(array('ERROR'));
        }
    }

    public function getScheduleBySerialStdSerialScd($serial_std, $serial_cdt, $date, $serial_crs, $day, $serial_scy,$serial_scd) {
		
        $course = $this->course->getCourseByStudentYear($serial_std, $serial_scy);
        $scheduleMandatories = $this->scheduele->getScheduleByCourseCreditDetailsMandatories($course->serial_crs, $serial_cdt, $date, $day);
        $scheduleOptionals = $this->scheduele->getScheduleByCourseCreditDetailsOptionlSubjects($serial_cdt, $serial_std, $date,$day);
        return count($scheduleMandatories) + count($scheduleOptionals);
    }

    /**
     * Método que devuelve el la lista de estudiantes y si tienen registro de asistencia
     * @since   2017-08-03
     * @author  Fernando Salas <rfsalas@rutatec.com>
     *
     * @param   void
     * @return  array types attendance
     * 
     * @edit    2017-08-03<br />
     *          Fernando Salas <rfsalas@rutatec.com><br />
     *          Creación del método<br/>
     *          #edit1
     */
    public function postListAttendanceTypes() {
        $typesAttendance = $this->attendance->getAttendanceTypes();
        return response()->json($typesAttendance);
    }

    /**
     * Método que devuelve el la lista de estudiantes y si tienen registro de asistencia
     * @since   2017-08-03
     * @author  Fernando Salas <rfsalas@rutatec.com>
     *
     * @param   array $request datos para guardar la asistencia
     * @return  boolean true
     * 
     * @edit    2017-08-03<br />
     *          Fernando Salas <rfsalas@rutatec.com><br />
     *          Creación del método<br/>
     *          #edit1
     */
    public function postSaveStudentAttendance(Request $request) {
        try {
            $this->validate($request, [
                'serial_ace' => 'required',
                'serial_std' => 'required',
                'date_ace' => 'required',
                'type_ace' => 'required',
                'serial_scd' => 'required',
                'serial_usr' => 'required'
            ]);
            $result = $this->attendance->saveStudentAttendance(array($request->all()));
			
            return response()->json($result);
        } catch (Exception $ex) {
            return false;
        }
    }

    public function postAttendanceOptions(Request $request) {
        $scheduele = \App\Models\Schedule::find($request->serial_scd);
        $course = \App\Models\Course::find($scheduele->serial_crs);
        $schoolYear = \App\Models\SchoolYear::find($course->serial_scy);
        //return response()->json($schoolYear);
        $attenance = \App\Models\Attendance::find($request->serial_ace);
        //return response()->json($attenance);
        return response()->json(array('observations' => $schoolYear->observations, 'attendance' => $attenance));
    }

}
