<?php

namespace App\Http\Controllers;

use App\Models\Device;
use Illuminate\Http\Request;
use Tymon\JWTAuth\JWTAuth;
use App\Repositories\UserRepository;

class AuthController extends Controller {

    /**
     * @var \Tymon\JWTAuth\JWTAuth
     */
    protected $jwt;
    protected $user;

    public function __construct(JWTAuth $jwt, UserRepository $user) {
        $this->jwt = $jwt;
        $this->user = $user;
    }

    /**
     * Método para login de usuario
     * @since   2017-02-15
     * @author  Fernando Salas <rfsalas@rutatec.com>
     *
     * @param   array $request
     * @return  array(token,user)
     *
     */
    public function postLogin(Request $request) {
        $this->validate($request, [
            'username_usr' => 'required',
            'password' => 'required',
            'token' => 'required'
        ]);
        try {
            $credentials = ['user' => strtolower($request->get('username_usr')), 'password' => $request->get('password')];
            $user = $this->user->getUser($credentials);
            if ($user != null) {
                $token = $this->jwt->fromUser($user);
                //save token registration on devices table
                $device = Device::where('token', $request->get('token'))
                    ->where('user_id', $user->serial_usr)
                    ->first();
                if (!$device) {
                    $device = new Device();
                    $device->token = $request->get('token');
                    $device->user_id = $user->serial_usr;
                    $device->platform = $request->get('platform') ? $request->get('platform') : null;
                    $device->app_version = $request->get('app_version') ? $request->get('app_version') : null;
                    $device->login_count = 1;
                    $device->save();
                } else {
                    if ($request->get('platform'))
                        $device->platform = $request->get('platform');
                    if ($request->get('app_version'))
                        $device->app_version = $request->get('app_version');
                    $device->login_count++;
                    $device->save();
                }
                return response()->json(array('token' => $token, 'serial_usr' => $user->serial_usr));
            }
            return response()->json(false, 404);
        } catch (JWTException $e) {

            return response()->json(false, 500);
        }
    }

    /**
     *
     */
    public function postLogout(Request $request) {
        $this->validate($request, [
            'serial_usr' => 'required',
            'token_dev' => 'required'
        ]);
        try {
            $this->jwt->invalidate();
            //save token registration on devices table
            $device = Device::where('token', $request->get('token_dev'))->where('user_id', $request->get('serial_usr'))->first();
            if ($device) {
                $device->delete();
            }
            return response()->json('success', 200);
            return response()->json(false, 404);
        } catch (TokenExpiredException $e) {

            return response()->json(false, 500);
        } catch (TokenInvalidException $e) {

            return response()->json(false, 500);
        } catch (JWTException $e) {

            return response()->json(false, 500);
        }
    }

}
