<?php

namespace App\Http\Controllers;

use App\Models\Device;
use App\Models\Message;
use App\Models\MessageThreadMessages;
use App\Models\UserProfile;
use App\Repositories\MessageRepository;
use App\Repositories\UserProfileRepository;
use App\Repositories\UserRepository;
use App\Repositories\MailSuggestoinRepository;
use Illuminate\Http\Request;

use Laravel\Lumen\Routing\Controller as BaseController;
use League\Flysystem\Exception;


class MessageController extends BaseController
{

    protected $message;
    protected $userProfile;
    protected $user;
    protected $mail;

    public function __construct(MessageRepository $message, UserProfileRepository $userProfile, UserRepository $user, MailSuggestoinRepository $mail)
    {
        $this->message = $message;
        $this->userProfile = $userProfile;
        $this->user = $user;
        $this->mail = $mail;
    }

    public function getMessagesByUser($serial_usr)
    {
        $messages = $this->message->getMessagesByUser($serial_usr, $status = 'all');
        $answerMessage = $this->message->getAnswerMessagesByUser($serial_usr);
        foreach ($messages as $message) {
            $message->message_msg = mb_substr(strip_tags(html_entity_decode($message->message_msg)), 0, 70,"utf-8");
            $countAnswerMsg = isset($answerMessage[$message->serial_msg]) ? $answerMessage[$message->serial_msg]:0;
            $message->subject_msg = ($countAnswerMsg > 0) ? '(Respondido) ' . $message->subject_msg: $message->subject_msg;

        }
        return response()->json($messages);
    }


    public function getDetailMessage($serial_msg,$strip_tags = null)
    {
        $message = Message::find($serial_msg);
        $userProfileReceive = $this->userProfile->getUserProfilesMessages($message->serial_usr_receive,$message->serial_prf);
        $threadMessageID = $this->message->getThreadMessageID($message->serial_msg);
        if ($threadMessageID) {
            $threadMessages = $this->message->getThreadMessage($threadMessageID->serial_mth, $message->send_date_msg);
            if(count($threadMessages)){
                $msg = '-------------------------------------------------------';
                foreach ($threadMessages as $threadMessage){
                    $msg = $msg."\n" . 'Enviado: ' . $threadMessage->send_date_msg ."\n" . 'De: ' . $threadMessage->user_from_name_msg . "\n" . 'Para: ' . $threadMessage->user_to_name_msg
                        . "\n" . 'Asunto: ' . $threadMessage->subject_msg . "\n". "\n" . $threadMessage->message_msg . "\n". "\n" . '-------------------------------------------------------'. "\n";
                }
                if($strip_tags != null){
                    $message->message_msg = html_entity_decode($message->message_msg . "\n" . "\n" . "\n" . $msg);
                } else {
                    $message->message_msg = strip_tags(html_entity_decode($message->message_msg . "\n" . "\n" . "\n" . $msg));
                }
            } else {
                if($strip_tags != null){
                    $message->message_msg = html_entity_decode($message->message_msg);
                } else {
                    $message->message_msg = strip_tags(html_entity_decode($message->message_msg));
                }
            }
            if($userProfileReceive){
                $threadAnswerMessages = $this->message->getAnswerMessage($threadMessageID->serial_mth, $serial_msg, $message->serial_usr_receive);
                $message->can_send_messages = (($message->deleted_msg == 'NO') && (count($threadAnswerMessages) == 0)) ? 'YES' : 'NO';
                $message->subject_msg = (count($threadAnswerMessages) > 0) ? $message->subject_msg . ' (Respondido)' : $message->subject_msg;
                $message->serial_prf_receive = $userProfileReceive->serial_prf;
            } else {
                $message->can_send_messages = 'NO';
                $message->serial_prf_receive = null;
            }
            $message->serial_mth = $threadMessageID->serial_mth;
        } else {
            if($strip_tags != null){
                $message->message_msg = html_entity_decode($message->message_msg);
            } else {
                $message->message_msg = strip_tags(html_entity_decode($message->message_msg));
            }
            $message->can_send_messages = 'NO';
        }
        return response()->json($message);
    }

    public function postDeleteMessage(Request $request)
    {
        $this->validate($request, [
            'serial_msg' => 'required',
        ]);
        try {
            $message = Message::find($request->input('serial_msg'));
            $message->deleted_msg = 'YES';
            $message->save();
            return response()->json(true);

        } catch (\Exception $ex) {
            return response()->json(false);
        }
    }

    public function postReadMessage(Request $request)
    {
        $this->validate($request, [
            'serial_msg' => 'required',
        ]);
        try {
            $message = Message::find($request->input('serial_msg'));
            $message->checked_msg = 'YES';
            $message->save();
            return response()->json(true);

        } catch (\Exception $ex) {
            return response()->json(false);
        }
    }

    public function getUnreadMessagesByUser($serial_usr)
    {
        $unreadMessages = $this->message->getMessagesByUser($serial_usr, $status = 'unread');
        foreach ($unreadMessages as &$message) {
            $message->message_msg = mb_substr(strip_tags(html_entity_decode($message->message_msg)), 0, 70,"utf-8");
        }
        return response()->json($unreadMessages);
    }

    public function getDeletedMessages($serial_usr)
    {
        $deletedMessages = $this->message->getMessagesByUser($serial_usr, $status = 'deleted');
        foreach ($deletedMessages as &$message) {
            $message->message_msg = mb_substr(strip_tags(html_entity_decode($message->message_msg)), 0, 70,"utf-8");
        }
        return response()->json($deletedMessages);
    }

    public function postDeleteMessageList(Request $request)
    {
        $this->validate($request, [
            'messages' => 'required',
        ]);
        $messages = json_decode($request->input('messages'));
        foreach ($messages as $message) {
            $msg = Message::find($message);
            $msg->deleted_msg = 'YES';
            $msg->save();
        }
    }

    /**
     * Método que guarda la respuesta de un mensaje con notificaciones push
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @params $request
     **/
    public function postResponseMessage(Request $request){
        try {
            $message = $request->all();
            $reSubjectMsg = "RE:";
            if (strncasecmp($message['subject_msg'], $reSubjectMsg, 3) !== 0){
                $message['subject_msg'] = 'RE: '. $message['subject_msg'];
            }
            $saveMessage = $this->message->saveMessage($message);
            $threadMessage = new MessageThreadMessages();
            $threadMessage->serial_mth = $message['serial_mth'];
            $threadMessage->serial_msg = $saveMessage->serial_msg;
            $threadMessage->save();
            if (env('FIREBASE_LEGACY_SERVER_KEY') != '') {
                $deviceArray = Device::where('user_id', $message['serial_usr_receive'])->get();
                foreach ($deviceArray as $device) {
                    $msg = array
                    (
                        'message' => $message['message_msg'],
                        'title' => $message['subject_msg'],
                        'vibrate' => 1,
                        'sound' => 1,
                        'largeIcon' => 'large_icon',
                        'smallIcon' => 'small_icon',
                        'priority' => 'high'
                    );
                    $fields = array
                    (
                        'to' => $device->token,
                        'notification' => $msg
                    );
                    $headers = array
                    (
                        'Authorization: key=' . env('FIREBASE_LEGACY_SERVER_KEY'),
                        'Content-Type: application/json'
                    );

                    $ch = curl_init();
                    curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/fcm/send');
                    curl_setopt($ch, CURLOPT_POST, true);
                    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
                    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
                    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($fields));

                    $result = curl_exec($ch);

                    curl_close($ch);
                }
            }
            $sendMail = $this->mail->sendMailMessage($message,$saveMessage);
            if($sendMail == true){
                return response()->json(['status' => 'Mensaje enviado correctamente'], 200);
            } else {
                return response()->json(['status' => 'No se pudo enviar el mensaje'], 200);
            }

        } catch (Exception $exception) {
            return $exception;
        }
    }

    /**
     * Método que envía notificaciones push
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @params $message (usuario, asunto y mensaje)
     *
     **/
    public function sendPushNotification($message)
    {
        $deviceArray = Device::where('user_id', $message['serial_usr_receive'])->get();
        foreach ($deviceArray as $device) {
            $msg = array
            (
                'message' => $message['message_msg'],
                'title' => $message['subject_msg'],
                'vibrate' => 1,
                'sound' => 1,
                'largeIcon' => 'large_icon',
                'smallIcon' => 'small_icon',
                'priority' => 'high'
            );
            $typePlatform = $device->platform;
            $typePlatformAndroid = "android";
            if (strncasecmp($typePlatform, $typePlatformAndroid, 7) === 0){
                $fields = array
                (
                    'to' => $device->token,
                    'data' => $msg
                );
                $headers = array
                (
                    'Authorization: key=AIzaSyDoeTs9uaAsTR4SEV9Rtk12HuLnOdbcDgg',
                    'Content-Type: application/json'
                );
            } else {
                $fields = array
                ('to' => $device->token,
                    'notification' => $msg
                );
                $headers = array
                ('Authorization: key=AIzaSyDoeTs9uaAsTR4SEV9Rtk12HuLnOdbcDgg',
                    'Content-Type: application/json'
                );
            }
            // dd(json_encode($fields));
            $ch = curl_init();
            //curl_setopt($ch, CURLOPT_URL, 'https://android.googleapis.com/gcm/send');
            curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/fcm/send');
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($fields));

            $result = curl_exec($ch);

            curl_close($ch);
        }
        echo $result;


    }


}