<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Repositories\PeriodRepository;
use App\Repositories\SchoolYearRepository;
use Laravel\Lumen\Routing\Controller as BaseController;

class PeriodController extends BaseController {

    protected $period;
    protected $schoolYear;

    public function __construct(PeriodRepository $period, SchoolYearRepository $schoolYear) {
        $this->period = $period;
        $this->schoolYear = $schoolYear;
    }
    
    /**
     * Método para obtener datos de subperiodo por serial
     * @since   2018-04-05
     * @param   integer serial_std serial estudiante
     * @param   integer serial_scy serial anio
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
   public function getPeriodsByYearByStudent($serial_std, $serial_scy) {

        $period = $this->period->getPeriodsByYearByStudent($serial_std, $serial_scy);
         
        return response()->json($period);
    }
    
     /**
     * Método para obtener los periodos del año lectivo actual
     * @since   2018-04-05
     * @param   integer serial_std serial estudiante
     * @author  Fernando Salas <rfsalas@rutatec.com><br /><br/>
     * @return  json $periods lista de periodos más la opción de final del año
     *
     */
     public function getPeriods($serial_std) {
        $schoolYear = $this->schoolYear->getCurrentSchoolYear();
        $periods = $this->period->getPeriodsByYearByStudent($serial_std, $schoolYear->serial_scy)->toArray();
        $endYear = array('serial_prd' => 0, 'name_prd' => 'FINAL DEL AÑO');
        array_push($periods, $endYear);
        foreach ($periods as &$prd) {
            $prd['serial_scy'] = $schoolYear->serial_scy;
        }
        return response()->json($periods);
    }

}
