<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Repositories\ScheduleRepository;
use Laravel\Lumen\Routing\Controller as BaseController;
use App\Repositories\SchoolYearRepository;
use App\Repositories\CourseRepository;
use App\Repositories\EnumRepository;
use App\Repositories\PeriodRepository;
use App\Repositories\OptionalSubjectRepository;

class ScheduleController extends BaseController {

    protected $schedule;
    protected $schoolYear;
    protected $course;
    protected $enum;
    protected $period;
    protected $optionalSubject;

    public function __construct(ScheduleRepository $schedule, SchoolYearRepository $schoolYear = null, CourseRepository $course = null, EnumRepository $enum = null, PeriodRepository $period = null, OptionalSubjectRepository $optionalSubject = null) {
        $this->schedule = $schedule;
        $this->schoolYear = $schoolYear;
        $this->course = $course;
        $this->enum = $enum;
        $this->period = $period;
        $this->optionalSubject = $optionalSubject;
    }

    /**
     * Método que devuelve el horario por curso fecha dia
     * @since   2018-04-14
     * @author  Erick Vaca <epvaca@rutatec.com>
     *
     * @param   array $request 
     * @return  ListObject $schedule
     * 
     * @edit    2018-04-14<br />
     *          Erick Vaca <epvaca@rutatec.com><br />
     *          Creación del método<br/>
     *          #edit1
     */
    public function postScheduleByCourseDateDay(Request $request) {
        $this->validate($request, [
            'serial_crs' => 'required',
            'day' => 'required',
            'date' => 'required'
        ]);
        $schedules = $this->schedule->getScheduleByCourseDateDay($request->input('serial_crs'), $request->input('date'), $request->input('day'));

        return response()->json($schedules);
    }

    /**
     * Método que obtiene horario por serial_scd
     * @since   2018-04-20
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   $serial_scd id
     * @return  
     * 
     */
    public function getScheduleBySerialScd($serial_scd) {
        $schedule = $this->schedule->getScheduleBySerialScd($serial_scd);

        return response()->json($schedule);
    }

    /**
     * Método que devuelve el horario de un estudiante 
     * @since   2018-07-19
     * @author  Erick Vaca <epvaca@rutatec.com>
     *
     * @param   $serial_std serial estudiante
     * @return  ListObject $schedule
     * 
     * @edit    2018-07-19<br />
     *          Erick Vaca <epvaca@rutatec.com><br />
     *          Creación del método<br/>
     *          #edit1
     */
    public function getScheduleBySerialStd($serial_std) {

        //Obtener anio lectivo actual
        $currentSchoolYear = $this->schoolYear->getCurrentSchoolYear();

        $scheduleFinal = [];

        if ($currentSchoolYear) {
            $serial_scy = $currentSchoolYear->serial_scy;
            //Obtener curso del estudiante
            $course = $this->course->getCourseByStudentYear($serial_std, $serial_scy);
            if (sizeof($course) > 0) {
                $serial_crs = $course->serial_crs;
                $date = date('Y-m-d');
                //$date = "2018-01-01";
                $schedule = $this->schedule->getScheduleByCourseDate($serial_crs, $date);

                if (sizeof($schedule) > 0) {
                    $days = $this->enum->getDaysInSpanish();
                    //Obtener periodos a partir de la fecha y anio
                    $periodList = $this->period->getPeriodsByYearByStudent($serial_std, $serial_scy);
                    //Obtener periodo de la fecha actual                              
                    foreach ($periodList as $period) {
                        if ($period['start_date_prd'] <= $date && $period['end_date_prd'] >= $date) {
                            $serial_prd = $period['serial_prd'];
                            break;
                        }
                    }


                    //Armado de objeto segun requerido
                    foreach ($schedule as $val) {
                        $hasStudent = false;
                        if ($val->serial_lop) {

                            //Obtener la materia especifica del periodo
                            if (isset($serial_prd)) {
                                $optSbj = $this->optionalSubject->getOptionalSubjectByStudentSerialLopPeriod($val->serial_lop, $serial_std, $serial_prd);
                                if ($optSbj) {
                                    $hasStudent = true;
                                    $optionalSubjectDetail = $this->optionalSubject->getOptionalSubject($optSbj->serial_osb);
                                    $serial_emp = $optionalSubjectDetail->serial_emp;
                                    $subject_name = $optionalSubjectDetail->name_subject;
                                } else {
                                    $serial_emp = '';
                                    $subject_name = $val->name_lop;
                                }
                            } else {
                                $serial_emp = '';
                                $subject_name = $val->name_lop;
                            }
                        } elseif ($val->serial_sbc) {
                            $hasStudent = true;
                            $serial_emp = $val->serial_emp_sbc;
                            if ($val->name_csb_csb2) {
                                $subject_name = $val->name_csb_csb2 . ' - ' . $val->name_csb_csb;
                            } else {
                                $subject_name = $val->name_csb_csb;
                            }
                        } elseif ($val->serial_sps) {
                            $hasStudent = true;
                            $serial_emp = $val->serial_emp_sps;
                            $subject_name = $val->name_csb_csb3;
                        }
                        //Revisar si existe dia
                        if ($hasStudent) {
                            if (isset($scheduleArr[$val->day_scd])) {
                                //Agregar elemento hora
                                $scheduleArr[$val->day_scd]['hour'][] = [
                                    'start_hrs' => substr($val->start_at_cdt, 0, -3),
                                    'end_hrs' => substr($val->end_at_cdt, 0, -3),
                                    'subject_name' => $subject_name,
                                    'serial_emp' => $serial_emp
                                ];
                            } else {
                                $scheduleArr[$val->day_scd] = [
                                    'day' => $days[$val->day_scd],
                                    'hour' => [
                                        [
                                            'start_hrs' => substr($val->start_at_cdt, 0, -3),
                                            'end_hrs' => substr($val->end_at_cdt, 0, -3),
                                            'subject_name' => $subject_name,
                                            'serial_emp' => $serial_emp
                                        ]
                                    ]
                                ];
                            }
                        }
                    }
                    //Armado nuevo arrelgo sin key dia segun requerido
                    foreach ($scheduleArr as $valor) {
                        $scheduleFinal[] = $valor;
                    }
                }
            }
        }

        return response()->json($scheduleFinal);
    }

}
