<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Repositories\SchoolYearRepository;
use Laravel\Lumen\Routing\Controller as BaseController;

/**
 * Controlador para año lectivo
 * @since   2017-07-09
 * @author  Erick Vaca <epvaca@rutatec.com>
 *
 * @edit    2017-07-09<br />
 *          Erick Vaca <epvaca@rutatec.com><br /><br/>
 *          Creación del controlador<br/>
 *          #edit1
 */
class SchoolYearController extends BaseController {

    protected $schoolYear;

    /**
     * Constructor
     * @since   2016-07-09
     * @param   SchoolYearRepository  $schoolYear repositorio
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     *
     */
    public function __construct(SchoolYearRepository $schoolYear){
        $this->schoolYear = $schoolYear;
    }

    /**
     * Método para obtener años lectivos validos
     * @since   2016-07-09
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
    public function getAllSchoolYears(){

        $schoolYearList = $this->schoolYear->getAllSchoolYears();
        return response()->json($schoolYearList);        
    }

    /**
     * Método para obtener año lectivo actual
     * @since   2016-07-09
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
    public function getCurrentSchoolYear(){

        $currentSchoolYear = $this->schoolYear->getCurrentSchoolYear();

        return response()->json($currentSchoolYear);
        
    }


     /**
     * Método para obtener año lectivo por serial
     * @since   2018-03-15
     * @param serial_scy
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
    public function getSchoolYearBySerialScy($serial_scy){

        $schoolYear = $this->schoolYear->getSchoolYearBySerialScy($serial_scy);
        return response()->json($schoolYear);
        
    }

    /**
     * Método para obtener años lectivos validos
     * @since   2016-07-09
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
    public function getSchoolYearsActiveCurrent(){
        $schoolYearList = $this->schoolYear->getSchoolYearsActiveCurrent();
        return response()->json($schoolYearList);        
    }

    /**
     * Método para obtener años lectivos validos con toda su data
     * @since   2018-04-26
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
    public function getSchoolYearsDataActiveCurrent(){
        $schoolYearList = $this->schoolYear->getSchoolYearsDataActiveCurrent();
        return response()->json($schoolYearList);        
    }

    /**
     * Método para obtener años para admisiones
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-21
     * @return array $states
     */
    public function getSchoolYearForAdmissions(){
        $schoolYearList = $this->schoolYear->getSchoolYearForAdmissions();
        return response()->json($schoolYearList);
    }


}

