<?php

namespace App\Http\Controllers;

use App\Models\OptStudentCriteriaGrade;
use App\Models\Period;
use App\Models\SchoolYear;
use Illuminate\Http\Request;
use App\Repositories\SubjectPeriodActivityTypeRepository;
use App\Repositories\StudentCriteriaGradeRepository;
use App\Repositories\SubjectCourseRepository;
use App\Repositories\GlobalRepository;
use App\Repositories\QualitativeEquivalenceRepository;
use App\Repositories\OptSubjectPeriodActivityTypeRepository;
use App\Repositories\OptStudentCriteriaGradeRepository;
use App\Repositories\OptionalSubjectRepository;
use Laravel\Lumen\Routing\Controller as BaseController;


class SubjectPeriodActivityTypeController extends BaseController
{

    protected $subjectPeriodActivityType;
    protected $studentCriteriaGrade;
    protected $subjectCourse;
    protected $global;
    protected $qualitativeEquivalence;
    protected $optSubjectPeriodActivityType;
    protected $optStudentCriteriaGrade;
    protected $optionalSubject;

    public function __construct(SubjectPeriodActivityTypeRepository $subjectPeriodActivityType, StudentCriteriaGradeRepository $studentCriteriaGrade, SubjectCourseRepository $subjectCourse, GlobalRepository $global, QualitativeEquivalenceRepository $qualitativeEquivalence, OptSubjectPeriodActivityTypeRepository $optSubjectPeriodActivityType, OptStudentCriteriaGradeRepository $optStudentCriteriaGrade, OptionalSubjectRepository $optionalSubject)
    {
        $this->subjectPeriodActivityType = $subjectPeriodActivityType;
        $this->studentCriteriaGrade = $studentCriteriaGrade;
        $this->subjectCourse = $subjectCourse;
        $this->global = $global;
        $this->qualitativeEquivalence = $qualitativeEquivalence;
        $this->optSubjectPeriodActivityType = $optSubjectPeriodActivityType;
        $this->optStudentCriteriaGrade = $optStudentCriteriaGrade;
        $this->optionalSubject = $optionalSubject;
    }

    public function getGradesBySubjectBySubperiodByStudent($serial_prd, $serial, $serial_std, $type, $grade_type)
    {
        $period = Period::find($serial_prd);
        $subperiods = $period->subperiods;
        $periodGroupYear = $period->periodGroupYear;
        if ($type == "MANDATORY") {
            $subject = $this->subjectCourse->getSubjectCourse($serial);
            $subject->type = "MANDATORY";
            foreach ($subperiods as &$subperiod) {
                $activityTypes = $this->subjectPeriodActivityType->getActivityTypesBySubjectBySubperiodByStudent($serial_prd, $serial);
                foreach ($activityTypes as &$actType) {
                    $actType->average = $this->getAveragesByActivityTypeBySubperiod($serial, $type, $serial_prd, $subperiod->serial_sbp, $periodGroupYear->serial_scy, $serial_std, $actType->serial_att);
                    if ($grade_type == 'QUALITATIVE' && $actType->average != null) {
                        $subject->grade_type = 'QUALITATIVE';
                        $actType->average = $this->qualitativeEquivalence->convertQuantitativeToQualitative($actType->average, $periodGroupYear->serial_scy);
                    }
                    $subperiod->activityTypes = $activityTypes;
                }
            }
            $subject->subperiods = $subperiods;
            return response()->json($subject);
        } elseif ($type == "OPTATIVE") {
            $subject = $this->optionalSubject->getOptionalSubject($serial);
            $subject->type = "OPTATIVE";
            foreach ($subperiods as $subperiod) {
                $activityTypes = $this->optSubjectPeriodActivityType->getActivityTypesBySubjectBySubperiodByStudent($serial_prd, $serial);
                foreach ($activityTypes as &$actType) {
                    $actType->average = $this->getAveragesByActivityTypeBySubperiod($serial, $type, $serial_prd, $subperiod->serial_sbp, $periodGroupYear->serial_scy, $serial_std, $actType->serial_att);
                    if ($grade_type == 'QUALITATIVE' && $actType->average != null) {
                        $subject->grade_type = 'QUALITATIVE';
                        $actType->average = $this->qualitativeEquivalence->convertQuantitativeToQualitative($actType->average, $periodGroupYear->serial_scy);
                    }
                    $subperiod->activityTypes = $activityTypes;
                }
            }
            $subject->subperiods = $subperiods;
            return response()->json($subject);
        }
		
    }

    public function getAveragesByActivityTypeBySubperiod($serial, $type, $serial_prd, $serial_sbp, $serial_scy, $serial_std, $serial_att)
    {
        if ($type == "MANDATORY") {
            $activities = $this->studentCriteriaGrade->getActivitiesByActivityTypeBySubperiod($serial, $serial_prd, $serial_sbp, $serial_scy, $serial_std, $serial_att);
        } else {
            $activities = $this->optStudentCriteriaGrade->getActivitiesByActivityTypeBySubperiod($serial, $serial_prd, $serial_sbp, $serial_scy, $serial_std, $serial_att);
        }

        $schoolYear = SchoolYear::find($serial_scy);
        $prom = 0;
        $countGrades = 0;
        if (count($activities) > 0) {
            foreach ($activities as $activity) {
                if (!($activity->act_grade === NULL) && is_numeric($prom)) {
                    $actGrade = number_format($this->global->truncate($activity->act_grade, $schoolYear->grade_precision_scy), $schoolYear->grade_precision_scy);
                    $prom += $actGrade;
                    $countGrades++;
                }
            }
            if ($countGrades != 0) {
                $average = number_format($this->global->truncate($prom / $countGrades, $schoolYear->grade_precision_scy), $schoolYear->grade_precision_scy);;
                return $average;
            }
            return '';
        }
        return '';
    }

}