<?php

namespace App\Http\Controllers;

use Tymon\JWTAuth\JWTAuth;
use App\Repositories\UserRepository;
use App\Repositories\UserProfileRepository;
use App\Repositories\GuardianRepository;
use App\Repositories\StudentRepository;
use App\Repositories\EmployeeRepository;
use App\Repositories\StudentYearRepository;
use App\Repositories\SchoolYearRepository;
use Laravel\Lumen\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redis;

class UserController extends BaseController {

    /**
     * @var \Tymon\JWTAuth\JWTAuth
     */
    protected $jwt;
    protected $user;
    protected $guardian;
    protected $userProfile;
    protected $employee;
    protected $student;
    protected $studentYear;
    protected $schoolYear;
 

    public function __construct(JWTAuth $jwt, UserRepository $user, UserProfileRepository $userProfile, GuardianRepository $guardian, EmployeeRepository $employee, StudentRepository $student, StudentYearRepository $studentYear, SchoolYearRepository $schoolYear) {
        $this->jwt = $jwt;
        $this->user = $user;
        $this->userProfile = $userProfile;
        $this->guardian = $guardian;
        $this->employee = $employee;
        $this->student = $student;
        $this->studentYear = $studentYear;
        $this->schoolYear = $schoolYear;
    }

    public function postUserInfo(Request $request) {
        try {
            $this->validate($request, [
                'serial_usr' => 'required',
                'serial_prf' => 'required',
            ]);
            $schoolYear = $this->schoolYear->getCurrentSchoolYear();
            $user = array();
            switch ($request->input('serial_prf')) {
                case 2:
                    $guardian = $this->guardian->getGuardianInfo($request->input('serial_usr'));

                    $user['serial_grd'] = $guardian->serial_grd;
                    $user['last_name_grd'] = $guardian->last_name_grd;
                    $user['first_name_grd'] = $guardian->first_name_grd;
                    if ($guardian->status_usr == 'ACTIVE') {
                        $user['img_grd'] = $this->user->getImageUser($request->input('serial_usr'));
                        foreach ($guardian->students as $student) {
                            $student_year = $this->studentYear->getStudentYear($student->serial_std, $schoolYear->serial_scy);
                            $std = $this->student->findById($student->serial_std);
                            $img = $this->user->getImageUser($std->serial_usr);
                            if ($student_year != null) {
                                $students[] = array(
                                    'serial_std' => $student->serial_std,
                                    'last_name_std' => $student->first_name_std,
                                    'first_name_std' => $student->last_name_std,
                                    'img_std' => $img
                                );
                                $user['children'] = $students;
                            }
                        }
                    } else {
                        $user['children'] = array();
                    }
                   
                    break;
                case 3:
                    $student = $this->student->getStudentInfo($request->input('serial_usr'));
                    $students[] = array(
                        'serial_std' => $student->serial_std,
                        'last_name_std' => $student->first_name_std,
                        'first_name_std' => $student->last_name_std,
                        'img_std' => $this->user->getImageUser($request->input('serial_usr'))
                    );
                    $user['children'] = $students;
                    break;
                case 0:
                    $employee = $this->employee->getEmployeeInfo($request->input('serial_usr'));
                    $user['serial_emp'] = $employee->serial_emp;
                    $user['last_name_emp'] = $employee->last_name_emp;
                    $user['first_name_emp'] = $employee->first_name_emp;
                    $user['img_emp'] = $this->user->getImageUser($request->input('serial_usr'));
                    break;
            }
            
            return response()->json($user);
        } catch (\Tymon\JWTAuth\Exceptions\TokenExpiredException $e) {
            
        }
    }

    public function postIsUser(Request $request) {
        $this->validate($request, [
            'serial_usr' => 'required',
            'token' => 'required',
        ]);

        try {
            $redis = Redis::connection();
            $tokenRedis = $redis->get($request->input('serial_usr'));

            if ($tokenRedis == $request->input('token')) {
                return response()->json(true);
            }
            return response()->json(false);
        } catch (\Tymon\JWTAuth\Exceptions\TokenExpiredException $e) {

            return response()->json(['token_expired'], 500);
        } catch (\Tymon\JWTAuth\Exceptions\TokenInvalidException $e) {

            return response()->json(['token_invalid'], 500);
        } catch (\Tymon\JWTAuth\Exceptions\JWTException $e) {
            return response()->json(['token_absent' => $e->getMessage()], 500);
        }
    }



    /**
     * Método que devuelve usuario  por serial_usr
     * @since   2018-04-04     
     * @param   integer serial_usr serial_usr
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
    public function getUserBySerialusr($serial_usr){

        $user = $this->user->getUserBySerialusr($serial_usr);

        return response()->json($user);
        
    }

}
