<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Repositories\YearSubjectSkillsRepository;
use App\Repositories\SkillsRepository;
use Laravel\Lumen\Routing\Controller as BaseController;

/**
 * Controlador para destrezas por materia año
 * @since   2017-07-09
 * @author  Erick Vaca <epvaca@rutatec.com>
 *
 * @edit    2017-07-09<br />
 *          Erick Vaca <epvaca@rutatec.com><br /><br/>
 *          Creación del controlador<br/>
 *          #edit1
 */
class YearSubjectSkillsController extends BaseController {

    protected $yearSubjectSkills;
    protected $skills;

    /**
     * Constructor
     * @since   2016-07-09
     * @param   YearSubjectSkillsRepository  $yearSubjectSkills repositorio
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     *
     */
    public function __construct(YearSubjectSkillsRepository $yearSubjectSkills, SkillsRepository $skillsRepository){
        $this->yearSubjectSkills = $yearSubjectSkills;
        $this->skills = $skillsRepository;
    }

    /**
     * Método para inactivar configuracion de destreza por materias y destreza
     * @since   2016-07-09
     * @param   string subject_type tipo materia
     * @param   integer $serial_skl destreza
     * @param   integer $serial_subjects materias a afectar     
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
    public function inactivateYearSubjectSkillsBySubjectTypeSkill($subject_type,$serial_skl,$serial_subjects){

    	$updateData = array('status_yss' => 'INACTIVE');

        $result = $this->yearSubjectSkills->updateYearSubjectSkillsBySubjectTypeSkill($subject_type,$serial_skl,$serial_subjects,$updateData);

        return response()->json($result);
        
    }

    /**
     * Método para insertar configuracion de destreza por materias y destreza
     * @since   2016-07-09
     * @param   string subject_type tipo materia
     * @param   integer $serial_skl destreza
     * @param   integer $serial_subjects materias a afectar     
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
    public function insertYearSubjectSkillsBySubjectTypeSkill($subject_type,$serial_skl,$serial_subject, $order = null){    	

        $result = $this->yearSubjectSkills->insertYearSubjectSkillsBySubjectTypeSkill($subject_type,$serial_skl,$serial_subject,$order);

        return response()->json($result);        
    }

    /**
     * Método para activar configuracion de destreza por materias y destreza
     * @since   2016-07-09
     * @param   string subject_type tipo materia
     * @param   integer $serial_skl destreza
     * @param   integer $serial_subjects materias a afectar     
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
    public function activateYearSubjectSkillsBySubjectTypeSkill($subject_type,$serial_skl,$serial_subject){

    	$updateData = array('status_yss' => 'ACTIVE');

        $result = $this->yearSubjectSkills->updateYearSubjectSkillsBySubjectTypeSkill($subject_type,$serial_skl,$serial_subject,$updateData);

        return response()->json($result);
        
    }

    /**
     * Método para verificar si existe configuracion de destreza por materias y destreza
     * @since   2016-07-09
     * @param   string subject_type tipo materia
     * @param   integer $serial_skl destreza
     * @param   integer $serial_subjects materias a afectar     
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
    public function getYearSubjectSkillBySubjectTypeSkill($subject_type,$serial_skl,$serial_subject){

        $result = $this->yearSubjectSkills->getYearSubjectSkillBySubjectTypeSkill($subject_type,$serial_skl,$serial_subject);

        return response()->json($result);
        
    }


    /**
     * Método para reordenar destreza por materias y posicion
     * @since   2018-01-07
     * @param   string subject_type tipo materia
     * @param   integer $serial_skl destreza
     * @param   integer $serial_subjects materias a afectar     
     * @param   integer $position posicion destreza
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
    public function reorderYearSubjectSkillsBySubjectTypeSkill($subject_type,$serial_skl,$serial_subject,$position){       

        //Get all skills 
        $skillsList = $this->skills->getSkillsAssignedBySubjectType($serial_subject, $subject_type)->toArray();


        //Find current skill, backup and remove from array.
        $keySkill = array_search($serial_skl, array_column($skillsList, 'serial_skl'));
        $backupSkill = $skillsList[$keySkill];
        unset($skillsList[$keySkill]);

        //Insert remove skill in the position desired
        array_splice($skillsList, $position, 0, array($backupSkill));

        //Iterate array to reoder all skills with apropiate order and update db
        $i=1;
        foreach ($skillsList as &$skill) {
            $skill['order_yss'] = $i;      
            $updateData = array('order_yss' => $i);
            $result = $this->yearSubjectSkills->updateYearSubjectSkillsBySubjectTypeSkill($subject_type,$skill['serial_skl'],$serial_subject,$updateData);
            $i++;
        }
   

        return response()->json($result);        
    }


}

