<?php

namespace App\Repositories;

use App\Models\Attendance;
use App\Models\Employee;
use App\Models\SchoolSetup;
use App\Repositories\DateDayConfigurationRepository;
use App\Repositories\BaseRepository;

class AttendanceRepository extends BaseRepository {

    protected $modelClass = Attendance::class;

    protected $schedule;
    protected $studentOptionalSubject;
    protected $extracurricularActivitiesAttendance;
//    protected $course;
    //Declaración del constructor
    public function __construct(Attendance $attendance, DateDayConfigurationRepository $dateDayConfiguration, ScheduleRepository $scheduleRepository, StudentOptionalSubjectRepository $studentOptionalSubjectRepository,ExtracurricularActivitiesAttendanceRepository $extracurricularActivitiesAttendanceRepository) {
        $this->attendance = $attendance;
        $this->schedule = $scheduleRepository;
        $this->studentOptionalSubject = $studentOptionalSubjectRepository;
        $this->extracurricularActivitiesAttendance = $extracurricularActivitiesAttendanceRepository;
        $this->dateDayConfiguration = $dateDayConfiguration;
    }

    /**
     * Método que retorna section , especialidad, nivel por anio lectivo
     * @since   2017-07-15
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   void
     * @return  ListObject Section
     * 
     */
    public function getAttendanceStudentSubject($serial_std, $serial_scd, $serial_sbc, $serial_lop, $date) {
        $day = $this->dateDayConfiguration->getDateDayConfiguration($date);
        $query = $this->newQuery();
        $query->where('serial_std', '=', $serial_std);
        $query->where('serial_scd', '=', $serial_scd);
        if ($serial_lop != null) {
            $query->where('serial_sbc', '=', $serial_sbc);
        } else {
            $query->where('serial_sbc', '=', $serial_sbc);
        }
        $query->where('serial_ddc', '=', $day->serial_ddc);
        $query->where('status_ace', '=', 'ACTIVE');
        $result = $this->doQueryFirst($query);
        if ($result) {
            return $result;
        }
        return new Attendance;
    }

    /**
     * Método para devolver los tipos de asistencia
     * @since   2017-08-03
     * @author  Fernando Salas <rfsalas@rutatec.com>
     *
     * @param   void
     * @return  list tipos de asistencia
     * 
     * @edit    2017-08-03<br />
     *          Fernando Salas <rfsalas@rutatec.com><br />
     *          Creación del método<br/>
     *          #edit1
     */
    public function getAttendanceTypes() {
        return $typesAttendance = Attendance::$type_ace;
    }

    /**
     * Método para guardar o actualizar la asistencia por estudiante
     * @since   2017-08-03
     * @author  Fernando Salas <rfsalas@rutatec.com>
     *
     * @param   array $request datos de la asistencia
     * @return  boolean true
     * 
     * @edit    2017-09-04<br />
     *          Fernando Salas <rfsalas@rutatec.com><br />
     *          Corrección asistencia en caso de ser presente<br/>
     *          #edit1
     */
    public function saveStudentAttendance(array $request) {
        //Obtenemos la configuración del día a partir de la fecha enviada
        $day = $this->dateDayConfiguration->getDateDayConfiguration($request[0]['date_ace']);
        //se realiza la búsqueda para determinar si existe ya registrada la asistencia para ese día y horario
        $attendance = Attendance::where('serial_ace', '=', $request[0]['serial_ace'])
                ->where('status_ace', '=', 'ACTIVE')
                ->first();

        $schoolSetup= SchoolSetup::first();

        //validacion para que actualice las demás horas en caso de falta injustificada, presente o permiso
        $schedulesArray= array();
        $schedulesOptArray= array();
        //verificar hora a la que se registra con la hora del credito en el horario
        $hourRegister=date('H:i:s');
        $currentDay=date('Y-m-d');
        $creditDetail=$this->schedule->getCreditDetailBySchedule($request[0]['serial_scd']);
        $course=$this->schedule->getCourseBySchedule($request[0]['serial_scd']);

        $emp= Employee::where('serial_usr',$request[0]['serial_usr'])->where('status_emp','=','ACTIVE')->where('type_emp','like','%TEACHING%')->first();

        //guardar asistencia en extracurriculares
        $saveExtracurricularAttendances=false;
        //si es TOMAS MORO, si la hora de registro esta dentro de los rangos en el horario y si la falta es injustificada, presente o permiso/sin_uniforme
        if ($schoolSetup->serial_sst==9 && $emp && $currentDay==$request[0]['date_ace'] && $course->attendance_crs!='DAY' && (($creditDetail->start_at_cdt<=$hourRegister && $creditDetail->end_at_cdt>=$hourRegister)) && ($request[0]['type_ace'] == 'UNEXCUSED_ABSENCE' || $request[0]['type_ace'] == 'PRESENT' || $request[0]['type_ace'] == 'PERMISSION')) {
            //se obtiene las horas siguientes del horario a partir de la hora de registro
            $schedules = $this->schedule->getNextSchedulesBySchedule($request[0]['serial_scd']);
            //Si existen mas horas se genera el arreglo para el registro con los creditos del horario
            if (count($schedules) > 0) {
                foreach ($schedules as &$schedule) {

                    if ($schedule->serial_sbc) {
                        $schedulesArray[$schedule->serial_scd]['serial_scd'] = $schedule->serial_scd;
                        $schedulesArray[$schedule->serial_scd]['serial_sbc'] = $schedule->serial_sbc;
                        $schedulesArray[$schedule->serial_scd]['serial_lop'] = NULL;
                    } else if ($schedule->serial_lop) {
                        $schedulesArray[$schedule->serial_scd]['serial_scd'] = $schedule->serial_scd;
                        $schedulesArray[$schedule->serial_scd]['serial_lop'] = $schedule->serial_lop;
                        $schedulesArray[$schedule->serial_scd]['serial_sbc'] = NULL;
                        $schedulesOptArray[$schedule->serial_scd] = $schedule->serial_lop;
                    } else {
                        unset($schedule);
                    }
                }
            }
            //se verifica que el arreglo contenga solo las horas/masterias que toma el estudiante
            if (isset($schedulesOptArray)) {
                foreach ($schedulesOptArray as $keyAux => $scheduleStudent) {
                    if (!$this->studentOptionalSubject->checkLevelOptionalGroupByStudent($request[0]['serial_std'], $scheduleStudent)) {
                        unset($schedulesArray[$keyAux]);
                    }
                }
            }
        }
        $setAttendance=$attendance;
        //si no se cumple alguina de las condiciones anteriores se realiza un guardado normal
        if (count($schedulesArray) == 0) {
            $schedulesArray['no_array']['serial_scd'] = $request[0]['serial_scd'];
        }
        //intera los creditos del horario, en caso de no cumplirse alguna condicion realiza solo una interacion
        foreach ($schedulesArray as $schedule) {
            //Guardado comun
            //se verifica que la hora en la que se guarda sea la misma que envia el usuario para realizar el procedimiento normal
            if($schedule['serial_scd']==$request[0]['serial_scd']){
                //se actualiza si se encontró ya una asistencia registrada
                if ($attendance != null) {
                    if ($request[0]['type_ace'] == 'PRESENT') {
                        $attendance->status_ace = 'INACTIVE';
                        $attendance->save();
                        $setAttendance=$attendance;
                    } else {
                        $attendance->serial_std = $request[0]['serial_std'];
                        $attendance->type_ace = $request[0]['type_ace'];
                        $attendance->date_ace = $request[0]['date_ace'];
                        $attendance->serial_scd = $request[0]['serial_scd'];
                        $attendance->serial_usr = $request[0]['serial_usr'];
                        $attendance->without_uniform = isset($request[0]['without_uniform']) ? $request[0]['without_uniform'] : 'FALSE';
                        if (isset($request[0]['update_observations']) && $request[0]['update_observations'] == 'YES' && $schedule['serial_scd'] == $request[0]['serial_scd']) {
                            $attendance->serial_obs = isset($request[0]['serial_obs']) ? $request[0]['serial_obs'] : null;
                            $attendance->observation = isset($request[0]['serial_obs']) ? $request[0]['serial_obs'] : null;
                            $attendance->review = isset($request[0]['review']) ? $request[0]['review'] : null;
                        }
                        $attendance->serial_ddc = $day->serial_ddc;
                        $attendance->permission = $request[0]['type_ace'] == 'PERMISSION' ? 1 : 0;
                        if (isset($request[0]['serial_lop'])) {
                            $attendance->serial_lop = $request[0]['serial_lop'];
                            $attendance->save();
                            $setAttendance=$attendance;
                        } else {
                            $attendance->serial_sbc = $request[0]['serial_sbc'];
                            $attendance->save();
                            $setAttendance=$attendance;
                        }
                    }

                    //se crea un nuevo registro de asistencia
                } else {
                    if ($request[0]['type_ace'] != 'PRESENT') {
                        $attendance = new Attendance;
                        $attendance->serial_std = $request[0]['serial_std'];
                        $attendance->type_ace = $request[0]['type_ace'];
                        $attendance->date_ace = $request[0]['date_ace'];
                        $attendance->serial_scd = $request[0]['serial_scd'];
                        $attendance->serial_usr = $request[0]['serial_usr'];
                        $attendance->without_uniform = isset($request[0]['without_uniform']) ? $request[0]['without_uniform'] : 'FALSE';
                        if (isset($request[0]['update_observations']) && $request[0]['update_observations'] == 'YES') {
                            $attendance->serial_obs = isset($request[0]['serial_obs']) ? $request[0]['serial_obs'] : null;
                            $attendance->observation = isset($request[0]['serial_obs']) ? $request[0]['serial_obs'] : null;
                            $attendance->review = isset($request[0]['review']) ? $request[0]['review'] : null;
                        }
                        $attendance->serial_ddc = $day->serial_ddc;
                        $attendance->permission = $request[0]['type_ace'] == 'PERMISSION' ? 1 : 0;
                        //si es materia optativa
                        if (isset($request[0]['serial_lop'])) {
                            $attendance->serial_lop = $request[0]['serial_lop'];
                        } else {
                            $attendance->serial_sbc = $request[0]['serial_sbc'];
                        }
                        $attendance->save();
                        $setAttendance=$attendance;
                    }
                }
            }else{
                $saveExtracurricularAttendances=true;
                //guardar las demás
                $anotherAttendance = Attendance::where('date_ace', '=', $request[0]['date_ace'])
                    ->where('serial_std', '=', $request[0]['serial_std'])
                    ->where('serial_scd', '=', $schedule['serial_scd'])
                    ->where('serial_lop', '=', $schedule['serial_lop'])
                    ->where('serial_sbc', '=', $schedule['serial_sbc'])
                    ->where('status_ace', '=', 'ACTIVE')
                    ->first();
                //se actualiza si se encontró ya una asistencia registrada
                if ($anotherAttendance != null) {
                    if ($request[0]['type_ace'] == 'PRESENT') {
                        $anotherAttendance->status_ace = 'INACTIVE';
                        $anotherAttendance->save();
                    } else if($request[0]['type_ace'] == 'UNEXCUSED_ABSENCE' || $request[0]['type_ace'] == 'PERMISSION'){
                        $anotherAttendance->serial_std = $request[0]['serial_std'];
                        $anotherAttendance->type_ace = $request[0]['type_ace'];
                        $anotherAttendance->date_ace = $request[0]['date_ace'];
                        $anotherAttendance->serial_scd = $schedule['serial_scd'];
                        $anotherAttendance->serial_usr = $request[0]['serial_usr'];
                        $anotherAttendance->without_uniform = isset($request[0]['without_uniform']) ? $request[0]['without_uniform'] : 'FALSE';
                        $anotherAttendance->serial_ddc = $day->serial_ddc;
                        $anotherAttendance->permission = $request[0]['type_ace'] == 'PERMISSION' ? 1 : 0;
                        if (isset($schedule['serial_lop'])) {
                            $anotherAttendance->serial_lop = $schedule['serial_lop'];
                            $anotherAttendance->save();
                        } else {
                            $anotherAttendance->serial_sbc = $schedule['serial_sbc'];
                            $anotherAttendance->save();
                        }
                    }

                    //se crea un nuevo registro de asistencia
                } else {
                    if ($request[0]['type_ace'] == 'UNEXCUSED_ABSENCE' || $request[0]['type_ace'] == 'PERMISSION') {
                        $anotherAttendance = new Attendance;
                        $anotherAttendance->serial_std = $request[0]['serial_std'];
                        $anotherAttendance->type_ace = $request[0]['type_ace'];
                        $anotherAttendance->date_ace = $request[0]['date_ace'];
                        $anotherAttendance->serial_scd = $schedule['serial_scd'];
                        $anotherAttendance->serial_usr = $request[0]['serial_usr'];
                        $anotherAttendance->without_uniform = isset($request[0]['without_uniform']) ? $request[0]['without_uniform'] : 'FALSE';
                        $anotherAttendance->serial_ddc = $day->serial_ddc;
                        $anotherAttendance->permission = $request[0]['type_ace'] == 'PERMISSION' ? 1 : 0;
                        //si es materia optativa
                        if (isset($schedule['serial_lop'])) {
                            $anotherAttendance->serial_lop = $schedule['serial_lop'];
                        } else {
                            $anotherAttendance->serial_sbc = $schedule['serial_sbc'];
                        }
                        $anotherAttendance->save();
                    }
                }
            }

        }

        if($saveExtracurricularAttendances || ($schoolSetup->serial_sst==9 && $emp && $currentDay==$request[0]['date_ace'] && $course->attendance_crs=='DAY' && (($creditDetail->start_at_cdt<=$hourRegister && $creditDetail->end_at_cdt>=$hourRegister)) && ($request[0]['type_ace'] == 'UNEXCUSED_ABSENCE' || $request[0]['type_ace'] == 'PRESENT' || $request[0]['type_ace'] == 'PERMISSION'))){
            $schedule = $this->schedule->getScheduleBySerialScd($request[0]['serial_scd']);
            $this->extracurricularActivitiesAttendance->setAttendanceIfApply($request[0]['serial_std'],$request[0]['date_ace'],$schedule->day_scd,$request[0]['type_ace']);
        }

        return $setAttendance;
    }

}
