<?php

namespace App\Repositories;

use App\Models\Event;
use App\Models\EventProfile;
use App\Repositories\BaseRepository;

class EventProfileRepository extends BaseRepository {

    protected $modelClass = EventProfile::class;

     protected $event;
     protected $eventProfile;
    //Declaración del constructor
    public function __construct(Event $event,EventProfile $eventProfile) {
        $this->event = $event;
        $this->eventProfile=$eventProfile;
    }
    
    /**
     * Devuelve los eventos pertenecientes a todos los perfiles asignados de un usuario
     *
     * @param   array $profiles perfiles del usuario
     * 
     * @return  array $events
     * @throws  InvalidArgumentException
     * @since   2017-02-15
     * @author  Fernando Salas <rfsalas@rutatec.com>
     *
     */ 
   public function getEventProfile($profiles) {
        $data = [];
        foreach ($profiles as $profile) {
            array_push($data, $profile['serial_prf']);
        }

       $events = Event::join('event_profile', 'event_profile.serial_event', '=', 'event.serial_event');
       $events->join('profile', 'profile.serial_prf', '=', 'event_profile.serial_prf');
       $events->leftjoin('event_section', function ($join) {
           $join->on('event.serial_event', '=', 'event_section.serial_event');
           $join->where('status_evset', '=', 'ACTIVE');
       });
       $events->leftjoin('section', function ($join) {
           $join->on('event_section.serial_set', '=', 'section.serial_set');
           $join->where('section.status_set', '=', 'ACTIVE');
       });
       $events->whereIn('event_profile.serial_prf', $data);
       $events->where('status_evpf', '=', 'ACTIVE');
       $events->where('status_event', '=', 'ACTIVE');
       $events->where('status_prf', '=', 'ACTIVE');
       $events->selectRaw('event.serial_event,name_event,description_event,start_date_event,end_date_event,IF(count(color_set)>1,"#3a87ad",color_set) as color_set');
       $events->groupBy('event.serial_event', 'event_profile.serial_prf');
       $events->distinct();
       return $this->doQueryGet($events)->toArray();
    }

}
