<?php

namespace App\Repositories;

use App\Models\IncidenceCategory;
use App\Repositories\BaseRepository;

/**
 * Repositorio para manejo de Incidencia Categoria
 * @since   2018-03-09
 * @author  Erick Vaca <epvaca@rutatec.com>
 *
 * @edit    2018-03-09<br />
 *          Erick Vaca <epvaca@rutatec.com><br /><br/>
 *          Creación del archivo<br/>
 *          #edit1
 */
class IncidenceCategoryRepository extends BaseRepository {

    protected $modelClass = IncidenceCategory::class;

    //Declaración del constructor
    public function __construct(IncidenceCategory $incidenceCategory) {
        $this->incidenceCategory = $incidenceCategory;
    }
  


    /**
     * Método que guarda categoria
     * @since   2018-03-12
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   array $data
     * @return  
     * 
     */
    public function saveIncidenceCategory($data) {

        //se realiza la búsqueda para determinar si existe ya registrada la categoria padre
        $incidence = $this->getIncidenceCategoryBySerialIca($data['serial_ica']);       

         //se actualiza si se encontró ya una categoria padre registrada
        if ($incidence != null) {
            if (isset($data['_destroy'])) {//if (isset($data['_destroy']) {
                $incidence->status_ica = 'INACTIVE';
                $incidence->save();
            } else { //UPDATE                   
                $incidence->name_ica = $data['name_ica'];     
                $incidence->attendance_relation_ica = $data['attendance_relation_ica'];              
                $incidence->save();                
            }
        }else{
            //Crea nuevo registro
            $incidence = new IncidenceCategory;

            $incidence->serial_scy = $data['serial_scy'];        
            $incidence->name_ica = $data['name_ica'];                   
            $incidence->incidence_serial_ica = $data['incidence_serial_ica'];
            $incidence->attendance_relation_ica = $data['attendance_relation_ica'];
            $incidence->status_ica = 'ACTIVE';
            $incidence->save();

        }
        return $incidence;        
    }



    /**
     * Método que devuelve los tipos de relacion de asistencia disponibles para incidencias
     * @since   2018-03-12<
     * @author  Erick Vaca <epvaca@rutatec.com>
     * @return  json resultado
     *
     */
    public function incidenceAttendanceRelations(){

        return $attendanceRelations = IncidenceCategory::$attendance_relation_ica;
    }

    /**
     * Método para obtener categorias de incidencia por anio
     * @since   2018-03-13
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   int $serial_scy serial del anio
     * @return  Categories array
     * 
     */
    public function incidenceCategoriesByYear($serial_scy) {

        $query = $this->newQuery();        

       $query->leftjoin('incidence_category as ic2', function($join) {
            $join->on('ic2.serial_ica', '=', 'incidence_category.incidence_serial_ica');
            $join->where('ic2.status_ica', '=', 'ACTIVE');
        });

        $query->where('incidence_category.serial_scy', $serial_scy)
            ->where('incidence_category.status_ica', 'ACTIVE');   
        $query->selectRaw('incidence_category.*,ic2.name_ica as name_parent');
        $query->orderBy('ic2.serial_ica','ASC');
        $query->orderBy('incidence_category.serial_ica','ASC');

         return $this->doQueryGet($query);
    }


    /**
     * Método para obtener subcategorias por anio
     * @since   2018-03-17
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   int $serial_scy serial del anio
     * @return  Subcategories array
     * 
     */
    public function incidenceSubcategoriesByYear($serial_scy) {

        $query = $this->newQuery();        

       $query->join('incidence_category as ic2', function($join) {
            $join->on('ic2.serial_ica', '=', 'incidence_category.incidence_serial_ica');
            $join->where('ic2.status_ica', '=', 'ACTIVE');
        });

        $query->where('incidence_category.serial_scy', $serial_scy)
            ->where('incidence_category.status_ica', 'ACTIVE');   
        $query->selectRaw('incidence_category.*,ic2.name_ica as name_parent,ic2.type_incidence_ica as type_incidence');
        $query->orderBy('ic2.name_ica','ASC');
        $query->orderBy('incidence_category.name_ica','ASC');

         return $this->doQueryGet($query);
    }


    /**
     * Método para obtener subcategorias por anio que tengan configuracion
     * @since   2018-03-24
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   int $serial_scy serial del anio
     * @return  Subcategories array
     * 
     */
    public function incidenceSubcategoriesByYearWithSetup($serial_scy) {

        $query = $this->newQuery();        

        $query->join('incidence_category as ic2', function($join) {
            $join->on('ic2.serial_ica', '=', 'incidence_category.incidence_serial_ica');
            $join->where('ic2.status_ica', '=', 'ACTIVE');
        });
        $query->join('incidence_setup as is', 'is.serial_ica', '=', 'incidence_category.serial_ica');

        $query->where('incidence_category.serial_scy', $serial_scy);
        $query->where('incidence_category.status_ica', 'ACTIVE'); 
        $query->where('is.status_ise', 'ACTIVE');   
        $query->selectRaw('DISTINCT incidence_category.serial_ica,incidence_category.*,ic2.name_ica as name_parent,ic2.type_incidence_ica as type_incidence');
        $query->orderBy('ic2.name_ica','ASC');
        $query->orderBy('incidence_category.name_ica','ASC');

         return $this->doQueryGet($query);
    }


     /**
     * Método que obtiene incidence category por serial_ica
     * @since   2018-04-02
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   $serial_ica id
     * @return  
     * 
     */
    public function getIncidenceCategoryBySerialIca($serial_ica) {
        $query = $this->newQuery();

        $query->where('serial_ica', '=', $serial_ica);  
        $query->where('status_ica', '=', 'ACTIVE');               

        return $this->doQueryFirst($query);
    }

}
