<?php

namespace App\Repositories;

use App\Models\IncidenceStudentDetail;
use App\Repositories\BaseRepository;

/**
 * Repositorio para manejo de Incidencia Student Detail
 * @since   2018-03-26
 * @author  Erick Vaca <epvaca@rutatec.com>
 *
 * @edit    2018-03-26<br />
 *          Erick Vaca <epvaca@rutatec.com><br /><br/>
 *          Creación del archivo<br/>
 *          #edit1
 */
class IncidenceStudentDetailRepository extends BaseRepository {

    protected $modelClass = IncidenceStudentDetail::class;

    //Declaración del constructor
    public function __construct(IncidenceStudentDetail $incidenceStudentDetail) {
        $this->incidenceStudentDetail = $incidenceStudentDetail;
    }
  


    /**
     * Método que guarda detalle de incidencia de estudiante
     * @since   2018-03-26
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   array $data
     * @return  
     * 
     */
    public function saveIncidenceStudentDetail($data) {

        //se realiza la búsqueda para determinar si existe ya configuracion
        $isd = IncidenceStudentDetail::where('serial_isd', '=', $data['serial_isd'])
                ->where('status_isd', '=', 'ACTIVE')
                ->first();

         //se actualiza si se encontró ya una configuracion activa registrada
        if ($isd != null) {
            if (isset($data['_destroy'])) {
                $isd->status_isd = 'INACTIVE';
                $isd->save();
            } else { //UPDATE                                         
                $isd->total_isd = $data['total_isd'];
                $isd->cycle_isd = $data['cycle_isd']; 
                $isd->save();                
            }
        }else{            
                //Crea nuevo registro
                $isd = new IncidenceStudentDetail;

                $isd->serial_iss = $data['serial_iss'];        
                $isd->serial_sbc = $data['serial_sbc'];                   
                $isd->serial_osb = $data['serial_osb'];
                $isd->total_isd = 1;
                $isd->cycle_isd = 1;              
                $isd->status_isd = 'ACTIVE';
                $isd->save();
        }             
    }


    /**
     * Método que obtener student detail por seriales de summary y materia
     * @since   2018-03-30
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   $serial_iss serial
     * @param   $type_subject type_subject
     * @param   $serial_subject serial
     * @return  
     * 
     */
    public function getIncidenceStudentDetailBySerialIssSubject($serial_iss, $type_subject, $serial_subject) {
        $query = $this->newQuery();
        $query->where('serial_iss', $serial_iss);
        if ($type_subject == 'Obligatoria') {
            $query->where('serial_sbc', $serial_subject);
            $query->whereNull('serial_osb');
        } else {
             $query->where('serial_osb', $serial_subject);
             $query->whereNull('serial_sbc');
         }  
         
         $query->where('status_isd', 'ACTIVE');
         
         return $this->doQueryFirst($query);
     }


    /**
     * Método para borrar incidence student detail por serial_iss, usado en cron fixIncidences
     * @since   2018-10-16
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *     
     * @param   $serial_std serial
     * @param   $serial_sbp serial
     * @return  
     * 
     */
    public function deleteIncidenceStudentDetailBySerialIss($serial_iss) {
        IncidenceStudentDetail::where('serial_iss', '=', $serial_iss)
                ->where('status_isd', '=', 'ACTIVE')->delete();                
    }



}
