<?php

namespace App\Repositories;

use App\Models\IncidenceStudent;
use App\Repositories\BaseRepository;

/**
 * Repositorio para manejo de Incidencia Student
 * @since   2018-03-23
 * @author  Erick Vaca <epvaca@rutatec.com>
 *
 * @edit    2018-03-23<br />
 *          Erick Vaca <epvaca@rutatec.com><br /><br/>
 *          Creación del archivo<br/>
 *          #edit1
 */
class IncidenceStudentRepository extends BaseRepository {

    protected $modelClass = IncidenceStudent::class;

    //Declaración del constructor
    public function __construct(IncidenceStudent $incidenceStudent) {
        $this->incidenceStudent = $incidenceStudent;
    }
  


    /**
     * Método que guarda incidencia
     * @since   2018-03-23
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   array $data
     * @return  
     * 
     */
    public function saveIncidenceStudent($data) {

        //se realiza la búsqueda para determinar si existe ya registro
        $ist = $this->getIncidenceStudentBySerialIst($data['serial_ist']);

         //se actualiza si se encontró ya un registro
        if ($ist != null) {
            if (isset($data['delete_ist']) && $data['delete_ist']) {
                $ist->serial_usr_delete_ist = $data['serial_usr_delete_ist'];
                $ist->comentary_delete_ist = $data['comentary_delete_ist'];
                $ist->value_ist = $data['value_ist'];
                $ist->status_ist = 'INACTIVE';
                $ist->save();
            } else { //UPDATE  
                if (isset($data['fix_ist']) && $data['fix_ist']) {//UPDATE FIX
                    $ist->value_ist = $data['value_ist'];                    
                    $ist->serial_ica = $data['serial_ica'];
                    $ist->save();
                }else{//UPDATE NORMAL
                    $ist->comentary_ist  = $data['comentary_ist'];                
                    $ist->save();
                }                                           
            }
        }else{
            //Crea nuevo registro
            $ist = new IncidenceStudent;
            $ist->serial_ica = $data['serial_ica'];        
            $ist->serial_usr = $data['serial_usr'];                   
            $ist->serial_std = $data['serial_std'];
            $ist->serial_sbc = $data['serial_sbc'];
            $ist->serial_osb = $data['serial_osb'];
            $ist->serial_sbp = $data['serial_sbp'];
            $ist->serial_scd = $data['serial_scd'];
            $ist->by_subject_ist = $data['by_subject_ist'];
            $ist->date_ist = $data['date_ist'];            
            $ist->comentary_ist = $data['comentary_ist'];
            $ist->value_ist = $data['value_ist'];
            $ist->status_ist = 'ACTIVE';
            $ist->save();
        }
        return $ist;             
    }


    /**
     * Método que obtiene total de incidencias de estudiante en una fecha
     * @since   2018-03-24
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   $serial_std serial de estudiante
     * @param   $date fecha
     * @param   $serial_scd serial de horario
     * @return  
     * 
     */
    public function getIncidenceTotalsByStudentDate($serial_std, $date, $serial_scd = null) {
        $query = $this->newQuery();
        $query->where('serial_std', '=', $serial_std);
        $query->where('date_ist', '=', $date);
        $query->where('status_ist', '=', 'ACTIVE');  
        // $ist = IncidenceStudent::where('serial_std', '=', $serial_std)
        // ->where('date_ist', '=', $date);
        // $ist->where('status_ist', '=', 'ACTIVE');
        if($serial_scd){
            $query->where('serial_scd', '=', $serial_scd);
        }
        $query->selectRaw("COUNT(serial_ist) AS total");
        $query->first();
        $result = $this->doQueryFirst($query);
        return $result->total;
    }



    /**
     * Método que obtiene listado de incidencias de estudiante en una fecha con su resumen
     * @since   2018-03-24
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   $serial_std serial de estudiante
     * @param   $date fecha
     * @param   $serial_scd serial de horario
     * @return  
     * 
     */
    public function getIncidencesByStudentDate($serial_std, $date, $serial_scd = null) {
        $query = $this->newQuery();
        $query->join('incidence_student_summary AS iss', function($join){
             $join->on('iss.serial_ica', '=', 'incidence_student.serial_ica')
            ->on('iss.serial_std', '=', 'incidence_student.serial_std');         
        });


        $query->where('incidence_student.serial_std', '=', $serial_std);
        $query->where('date_ist', '=', $date);
        if($serial_scd){
            $query->where('serial_scd', '=', $serial_scd);
        }
        $query->where('status_ist', '=', 'ACTIVE');               
        $query->where('iss.status_iss', '=', 'ACTIVE');

        return $this->doQueryGet($query);
    }


     /**
     * Método que obtiene incidence student por serial_ist
     * @since   2018-03-24
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   $serial_ist id
     * @return  
     * 
     */
    public function getIncidenceStudentBySerialIst($serial_ist) {
        $query = $this->newQuery();

        $query->where('serial_ist', '=', $serial_ist);  
        $query->where('status_ist', '=', 'ACTIVE');
        $query->with('incidenceCategory');

        return $this->doQueryFirst($query);
    }


    /**
     * Método que obtiene listado de incidencias de estudiante en un anio y periodo
     * @since   2018-04-05
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   $serial_std serial de estudiante
     * @param   $serial_scy serial de anio
     * @param   $serial_prd serial de periodo
     * @return  
     * 
     */
    public function getIncidencesByStudentYearPeriod($serial_std, $serial_scy, $serial_prd) {
        $query = $this->newQuery();

        $query->join('incidence_category as ic', 'ic.serial_ica', '=', 'incidence_student.serial_ica'); 
        $query->join('subperiod as s', 's.serial_sbp', '=', 'incidence_student.serial_sbp');
        $query->join('schedule as sc', 'sc.serial_scd', '=', 'incidence_student.serial_scd');
        $query->join('credits_detail as cd', 'cd.serial_cdt', '=', 'sc.serial_cdt');
        $query->leftJoin('subject_course as sbc', 'sbc.serial_sbc', '=', 'incidence_student.serial_sbc');
        $query->leftJoin('subject as sbj', 'sbj.serial_sbj', '=', 'sbc.serial_sbj');
        $query->leftJoin('cat_subject as csb', 'csb.serial_csb', '=', 'sbj.serial_csb');

        $query->leftJoin('optional_subject as osb', 'osb.serial_osb', '=', 'incidence_student.serial_osb');        
        $query->leftJoin('cat_subject as csb2', 'csb2.serial_csb', '=', 'osb.serial_csb');

        $query->where('incidence_student.serial_std', '=', $serial_std);
        $query->where('s.serial_prd', '=', $serial_prd);  
        $query->where('ic.serial_scy', '=', $serial_scy);
        $query->where('status_ist', '=', 'ACTIVE');               
        $query->where('ic.status_ica', '=', 'ACTIVE');
        $query->where('s.status_sbp', '=', 'ACTIVE');
        $query->orderBy('date_ist','DESC');  

        $query->selectRaw("IFNULL(csb2.name_csb,csb.name_csb) as name_csb,                          
                    name_ica, comentary_ist, start_at_cdt, end_at_cdt, date_ist, value_ist
                    ");

        return $this->doQueryGet($query);
    }


    /**
     * Método que obtiene total de registros de una incidencia por serial_ica.
     * Usado para validar en la configuracion si se puede editar o no subcategoria/frecuencias.
     * @since   2018-04-14
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *     
     * @param   $serial_ica serial_ica     
     * @return  
     * 
     */
    public function getIncidenceStudentTotalsBySerialIca($serial_ica) {
        $query = $this->newQuery();
        $query->join('incidence_category as ic', 'ic.serial_ica', '=', 'incidence_student.serial_ica');         
        $query->where('ic.serial_ica', '=', $serial_ica);
        $query->where('ic.status_ica', '=', 'ACTIVE');
        $query->where('incidence_student.status_ist', '=', 'ACTIVE');
        
        $query->selectRaw("COUNT(serial_ist) AS total");
        $query->first();
        $result = $this->doQueryFirst($query);
        return $result->total;
    }


    /**
     * Método que obtiene total de registros de incidencias por serial_ica (padre/categoria).
     * Usado para validar en la configuracion si se puede editar o no categorias
     * @since   2018-04-15
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *     
     * @param   $serial_ica serial_ica     
     * @return  
     * 
     */
    public function getIncidenceStudentTotalsBySerialIcaParent($serial_ica) {
        $query = $this->newQuery();
        $query->join('incidence_category as ic', 'ic.serial_ica', '=', 'incidence_student.serial_ica');         
        $query->join('incidence_category as ic2', 'ic2.serial_ica', '=', 'ic.incidence_serial_ica');

        $query->where('ic2.serial_ica', '=', $serial_ica);
        $query->where('ic.status_ica', '=', 'ACTIVE');
        $query->where('ic2.status_ica', '=', 'ACTIVE');
        $query->where('incidence_student.status_ist', '=', 'ACTIVE');
        
        $query->selectRaw("COUNT(serial_ist) AS total");
        $query->first();
        $result = $this->doQueryFirst($query);
        return $result->total;
    }


 /**
     * Método que obtiene listado de incidencias de estudiante en un anio, periodo y subperiodo usado
     * para correccion y recalculo de incidencias por orden de registro
     * @since   2018-10-16
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   $serial_std serial de estudiante
     * @param   $serial_scy serial de anio
     * @param   $serial_prd serial de periodo
     * @param   $serial_sbp serial de subperiodo
     * @return  
     * 
     */
    public function getIncidencesByStudentYearPeriodSubperiod($serial_std, $serial_scy, $serial_prd, $serial_sbp) {
        $query = $this->newQuery();

        $query->join('incidence_category as ic', 'ic.serial_ica', '=', 'incidence_student.serial_ica'); 
        $query->join('subperiod as s', 's.serial_sbp', '=', 'incidence_student.serial_sbp');
        $query->join('schedule as sc', 'sc.serial_scd', '=', 'incidence_student.serial_scd');
        $query->join('credits_detail as cd', 'cd.serial_cdt', '=', 'sc.serial_cdt');
        $query->leftJoin('subject_course as sbc', 'sbc.serial_sbc', '=', 'incidence_student.serial_sbc');
        $query->leftJoin('subject as sbj', 'sbj.serial_sbj', '=', 'sbc.serial_sbj');
        $query->leftJoin('cat_subject as csb', 'csb.serial_csb', '=', 'sbj.serial_csb');

        $query->leftJoin('optional_subject as osb', 'osb.serial_osb', '=', 'incidence_student.serial_osb');        
        $query->leftJoin('cat_subject as csb2', 'csb2.serial_csb', '=', 'osb.serial_csb');

        $query->where('incidence_student.serial_std', '=', $serial_std);
        $query->where('s.serial_prd', '=', $serial_prd);  
        $query->where('s.serial_sbp', '=', $serial_sbp); 
        $query->where('ic.serial_scy', '=', $serial_scy);
        $query->where('status_ist', '=', 'ACTIVE');               
        $query->where('ic.status_ica', '=', 'ACTIVE');
        $query->where('s.status_sbp', '=', 'ACTIVE');
        $query->orderBy('serial_ist','ASC');  

        $query->selectRaw("IFNULL(csb2.name_csb,csb.name_csb) as name_csb,serial_ist,serial_usr, serial_std,incidence_student.serial_sbp,incidence_student.serial_sbc,incidence_student.serial_osb, incidence_student.serial_scd, incidence_student.serial_ica,                     
                    name_ica, comentary_ist, date_ist, value_ist
                    ");

        return $this->doQueryGet($query);
    }



}
