<?php

namespace App\Repositories;

use App\Models\IncidenceStudentSummary;
use App\Repositories\BaseRepository;

/**
 * Repositorio para manejo de Incidencia Student Summary
 * @since   2018-03-26
 * @author  Erick Vaca <epvaca@rutatec.com>
 *
 * @edit    2018-03-26<br />
 *          Erick Vaca <epvaca@rutatec.com><br /><br/>
 *          Creación del archivo<br/>
 *          #edit1
 */
class IncidenceStudentSummaryRepository extends BaseRepository {

    protected $modelClass = IncidenceStudentSummary::class;

    //Declaración del constructor
    public function __construct(IncidenceStudentSummary $incidenceStudentSummary) {
        $this->incidenceStudentSummary = $incidenceStudentSummary;
    }
  


    /**
     * Método que guarda resumen de incidencia de estudiante
     * @since   2018-03-26
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   array $data
     * @return  
     * 
     */
    public function saveIncidenceStudentSummary($data) {

        //se realiza la búsqueda para determinar si existe ya configuracion
        $iss = $this->getIncidenceStudentSummaryBySerialIss($data['serial_iss']);

         //se actualiza si se encontró ya una configuracion activa registrada
        if ($iss != null) {
            if (isset($data['_destroy'])) {
                $iss->status_iss = 'INACTIVE';
                $iss->save();
            } else { //UPDATE                                         
                $iss->total_iss = $data['total_iss'];
                $iss->cycle_iss = $data['cycle_iss']; 
                $iss->save();                
            }
        }else{            
                //Crea nuevo registro
                $iss = new IncidenceStudentSummary;
                $iss->serial_sbp = $data['serial_sbp'];
                $iss->serial_ica = $data['serial_ica'];        
                $iss->serial_std = $data['serial_std'];  
                $iss->total_iss = $data['total_iss'];
                $iss->cycle_iss = $data['cycle_iss'];                                  
                $iss->status_iss = 'ACTIVE';
                $iss->save();
        }
        return $iss;              
    }


    /**
     * Método que obtener student summary por serial_iss
     * @since   2018-03-30
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   $serial_iss serial
     * @return  
     * 
     */
    public function getIncidenceStudentSummaryBySerialIss($serial_iss) {
        $iss = IncidenceStudentSummary::where('serial_iss', '=', $serial_iss)
                ->where('status_iss', '=', 'ACTIVE')
                ->first();
                return $iss;
    }


    /**
     * Método que obtener student summary por seriales de estudiante y categoria
     * @since   2018-03-30
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   $serial_ica serial
     * @param   $serial_std serial
     * @param   $serial_sbp serial
     * edit 2018-04-27
     * Aniadido serial_sbp para soporte por subperiodo
     * @return  
     * 
     */
    public function getIncidenceStudentSummaryBySerialIcaSerialStd($serial_ica, $serial_std, $serial_sbp) {
        $iss = IncidenceStudentSummary::where('serial_ica', '=', $serial_ica)
                ->where('serial_std', '=', $serial_std)
                ->where('serial_sbp', '=', $serial_sbp)
                ->where('status_iss', '=', 'ACTIVE')
                ->first();
                return $iss;
    }



    /**
     * Método para obtener student summary por seriales de estudiante y subperiodo. Usado para borrado y cron fix de incidencias
     * @since   2018-10-16
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *     
     * @param   $serial_std serial
     * @param   $serial_sbp serial
     * @return  
     * 
     */
    public function getIncidenceStudentSummaryBySerialStdSubperiod($serial_std, $serial_sbp) {
        $iss = IncidenceStudentSummary::where('serial_std', '=', $serial_std)                
                ->where('serial_sbp', '=', $serial_sbp)
                ->where('status_iss', '=', 'ACTIVE')->get()->toArray();
                return $iss;
    }


    /**
     * Método para borrar student summary por seriales de estudiante y subperiodo. 
     * @since   2018-10-16
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *     
     * @param   $serial_std serial
     * @param   $serial_sbp serial
     * @return  
     * 
     */
    public function deleteIncidenceStudentSummaryBySerialStdSubperiod($serial_std, $serial_sbp) {
        IncidenceStudentSummary::where('serial_std', '=', $serial_std)                
                ->where('serial_sbp', '=', $serial_sbp)
                ->where('status_iss', '=', 'ACTIVE')->delete();                
    }


}
