<?php
/**
 * Created by PhpStorm.
 * User: Henry Vivanco
 * Date: 7/9/2021
 * Time: 17:09
 */

namespace App\Repositories;


use App\Models\LockViewGrades;

class LockViewGradesRepository extends BaseRepository
{
    protected $lockViewGrades;

    public function __construct(LockViewGrades $lockViewGrades)
    {
        $this->lockViewGrades = $lockViewGrades;
    }

    /**
     * Método que devuelve si un parcial está bloqueado para vizualicación de notas para el app
     * @since   2021-09-27
     * @param   integer serial_std serial_std
     * @author   Henry Vivanco <hvvivanco@rutatec.com><br /><br/>
     * @return  json $viewGrade
     *
     */
    public function getSubPeriodViewGrade($serial_crs,$serial_scy,$serial_sbp){

        $viewGrade = LockViewGrades::where('serial_crs','=',$serial_crs)
            ->where('serial_scy','=',$serial_scy)
            ->where('serial_sbp','=',$serial_sbp)
            ->where('status_lvg','=','ACTIVE')
            ->first();

        return $viewGrade;

    }

    /**
     * Método que devuelve si un periodo está bloqueado para vizualicación de notas para el app
     * @since   2021-09-27
     * @param   integer serial_std serial_std
     * @author   Henry Vivanco <hvvivanco@rutatec.com><br /><br/>
     * @return  json $viewGrade
     *
     */
    public function getPeriodViewGrade($serial_crs,$serial_scy,$serial_prd){

        $viewGrade = LockViewGrades::where('serial_crs','=',$serial_crs)
            ->where('serial_scy','=',$serial_scy)
            ->where('serial_prd','=',$serial_prd)
            ->where('status_lvg','=','ACTIVE')
            ->first();

        return $viewGrade;

    }

    /**
     * Método que devuelve si promedio anual está bloqueado para vizualicación de notas para el app
     * @since   2021-09-27
     * @param   integer serial_std serial_std
     * @author   Henry Vivanco <hvvivanco@rutatec.com><br /><br/>
     * @return  json $viewGrade
     *
     */
    public function getYearViewGrade($serial_crs,$serial_scy){

        $viewGrade = LockViewGrades::where('serial_crs','=',$serial_crs)
            ->where('serial_scy','=',$serial_scy)
            ->where('status_lvg','=','ACTIVE')
            ->first();

        return $viewGrade;

    }

}