<?php

namespace App\Repositories;

use App\Models\Message;
use App\Models\MessageThread;
use App\Models\MessageThreadMessages;
use Illuminate\Support\Facades\DB;

class MessageRepository extends BaseRepository
{

    protected $message;
    protected $messageThread;
    protected $messageThreadMessages;

    //Declaración del constructor
    public function __construct(Message $message, MessageThread $messageThread, MessageThreadMessages $messageThreadMessages)
    {
        $this->message = $message;
        $this->messageThread = $messageThread;
        $this->messageThreadMessages = $messageThreadMessages;
    }


    public function getMessagesByUser($serial_usr, $status)
    {
        $messages = $this->messageThreadMessages->newQuery();
        $messages->join('message', 'message.serial_msg', '=', 'message_thread_messages.serial_msg');
        $messages->where('message.serial_usr_receive', '=', $serial_usr);
        $messages->where('message.removed_permanently_msg', '=', 'NO');
        $messages->whereIn('message_thread_messages.serial_mth', $this->messageThreadMessages->join('message', 'message.serial_msg', '=', 'message_thread_messages.serial_msg')
            ->where('message.serial_usr_receive', '=', $serial_usr)->groupBy('message_thread_messages.serial_mth')->select('message_thread_messages.serial_mth')->get());
        $messages->selectRaw('message.serial_msg,message.user_from_name_msg,message.subject_msg,LEFT(message.message_msg,120) as message_msg,
     message.checked_msg, message.deleted_msg,DATE_FORMAT(message.send_date_msg, "%d-%m-%Y %H:%i") as send_date_msg,message.attachment_msg, filename_msg, message.priority_msg');
        $messages1 = $this->message->newQuery();
        $messages1->where('serial_usr_receive', '=', $serial_usr);
        $messages1->where('type_msg', '=', 'PUBLIC');
        $messages1->where('removed_permanently_msg', '=', 'NO');
        $messages1->where('saved_msg', '=', 'NO');
        $messages1->selectRaw('message.serial_msg,message.user_from_name_msg,message.subject_msg,LEFT(message.message_msg,120) as message_msg,
     message.checked_msg, message.deleted_msg,DATE_FORMAT(message.send_date_msg, "%d-%m-%Y %H:%i") as send_date_msg,message.attachment_msg, filename_msg, message.priority_msg');
        if ($status == 'all') {
            $messages->where('message.deleted_msg', '=', 'NO');
            $messages1->where('deleted_msg', '=', 'NO');
        } elseif ($status == 'unread') {
            $messages->where('message.checked_msg', '=', 'NO');
            $messages1->where('message.checked_msg', '=', 'NO');
            $messages->where('message.deleted_msg', '=', 'NO');
            $messages1->where('deleted_msg', '=', 'NO');
        } elseif ($status == 'deleted') {
            $messages->where('message.deleted_msg', '=', 'YES');
            $messages1->where('deleted_msg', '=', 'YES');
        }
        return $this->doQueryGet($messages->union($messages1)->orderBy('serial_msg','DESC'));

    }

    /**
     * Método para obtener hilo de mensaje
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @params $request
     **/
    public function getThreadMessage($serial_mth,$send_date_msg){
        $threadMessage = $this->message->newQuery();
        $threadMessage->join('message_thread_messages as mtm','message.serial_msg','=','mtm.serial_msg');
        $threadMessage->where('mtm.serial_mth','=',$serial_mth);
        $threadMessage->where('message.send_date_msg','<',$send_date_msg);
        $threadMessage->orderBy('message.send_date_msg','desc');
        return $this->doQueryGet($threadMessage);
    }

    public function getThreadMessageID($serial_msg){
        $threadMessage = $this->message->newQuery();
        $threadMessage->join('message_thread_messages as mtm','message.serial_msg','=','mtm.serial_msg');
        $threadMessage->where('mtm.serial_msg','=',$serial_msg);
        return $this->doQueryFirst($threadMessage);
    }

    /**
     * Método para guardar respuesta a mensaje desde app
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @params $request
     **/
    public function saveMessage($message){
        $data = new Message();
        $data->serial_usr_receive = $message['serial_usr_receive'];
        $data->serial_prf = $message['serial_prf'];
        $data->serial_usr_send = $message['serial_usr_send'];
        $data->type_msg = $message['type_msg'];
        $data->user_from_name_msg = $message['user_from_name_msg'];
        $data->user_to_name_msg = $message['user_to_name_msg'];
        $data->subject_msg = $message['subject_msg'];
        $data->message_msg = $message['message_msg'];
        $data->checked_msg = 'NO';
        $data->saved_msg = 'NO';
        $data->deleted_msg = 'NO';
        $data->removed_permanently_msg = 'NO';
        $data->send_date_msg = Date("Y-m-d H:i:s");
        $data->check_date_msg = Date("Y-m-d H:i:s");
        $data->filename_msg = $message['filename_msg'];
        $data->attachment_msg = $message['attachment_msg'];
        $data->priority_msg = $message['priority_msg'];
        $data->save();
        return $data;
    }

    /**
     * Método para obtener numero de respuestas
     * a los mensajes recibidos por un usuario
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @params $request
     **/
    public function getAnswerMessagesByUser($serial_usr)
    {
        $msg2 = Message::leftJoin('message_thread_messages as mtm','message.serial_msg','=','mtm.serial_msg')
            ->selectRaw('mtm.serial_mth,message.serial_msg,message.serial_usr_send');
        $msg = Message::where('serial_usr_receive','=',$serial_usr)
            ->join('message_thread_messages as mtm','message.serial_msg','=','mtm.serial_msg')
            ->selectRaw('serial_mth,message.serial_msg as serial_msg,serial_usr_receive,send_date_msg');
        $count = DB::table(DB::raw("({$msg->toSql()}) as result1"))
            ->mergeBindings($msg->getQuery())
            ->leftJoin(DB::raw("({$msg2->toSql()}) as result2"), function ($join){
                $join->on('result2.serial_mth','=','result1.serial_mth')
                    ->on('result2.serial_msg','>','result1.serial_msg')
                    ->on('result2.serial_usr_send', '=', 'result1.serial_usr_receive');
            })
            ->groupBy('result1.serial_msg')
            ->selectRaw('result1.serial_msg, count(result2.serial_mth) as count_answer')->orderBy('result1.send_date_msg','DESC')
            ->pluck('count_answer','result1.serial_msg');
        return $count;
    }

    /**
     * Método para obtener numero de respuestas del mensaje
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @params $request
     **/
    public function getAnswerMessage($serial_mth,$serial_msg,$serial_usr_receive){
        $threadMessage = $this->message->newQuery();
        $threadMessage->join('message_thread_messages as mtm','message.serial_msg','=','mtm.serial_msg');
        $threadMessage->where('mtm.serial_mth','=',$serial_mth);
        $threadMessage->where('message.serial_msg','>',$serial_msg);
        $threadMessage->where('message.serial_usr_send','=',$serial_usr_receive);
        return $this->doQueryGet($threadMessage);
    }


}
