<?php

namespace App\Repositories;

use App\Models\QualitativeEquivalence;

class QualitativeEquivalenceRepository extends BaseRepository {

    protected $modelClass = QualitativeEquivalence::class;
    protected $qualitativeEquivalence;

    //Declaración del constructor
    public function __construct(QualitativeEquivalence $qualitativeEquivalence) {
        $this->qualitativeEquivalence = $qualitativeEquivalence;
    }


   /**
     * Método para convertir una calificación cuantitativa a cualitativa
     * @since   2018-05-17
     * @param   integer $grade calificación
     * @param   integer $serial_scy serial del año lectivo
     * @author  Fernando Salas <rfsalas@rutatec.com><br /><br/>
     * @return  $code_qeq
     *
     */
   public function convertQuantitativeToQualitative($grade, $serial_scy) {
       
        if (is_numeric($grade)) {
            $schoolYear = \App\Models\SchoolYear::find($serial_scy);
            $maxGrade = $schoolYear->school_max_grade_scy;
            $qualitativesEquivalence = $schoolYear->qualitativeEquivalences()->where('status_qeq', '=', 'ACTIVE')->orderBy('higher_percentage_qeq')->get();
            $percent = ($grade / $maxGrade) * 100;
            foreach ($qualitativesEquivalence as $qe) {
                if ($percent >= $qe->lower_percentage_qeq && $percent <= $qe->higher_percentage_qeq) {
                    return $qe->code_qeq;
                }
            }
        } else {
            return $grade;
        }
    }

}
