<?php

namespace App\Repositories;

use App\Models\SchoolYear;
use App\Repositories\BaseRepository;

/**
 * Repostiorio para año lectivo
 * @since   2017-07-09
 * @author  Erick Vaca <epvaca@rutatec.com>
 *
 * @edit    2017-07-09<br />
 *          Erick Vaca <epvaca@rutatec.com><br /><br/>
 *          Creación del archivo<br/>
 *          #edit1
 */
class SchoolYearRepository extends BaseRepository {

    protected $modelClass = SchoolYear::class;

    //Declaración del constructor
    public function __construct(SchoolYear $schoolYear) {
        $this->schoolYear = $schoolYear;
    }
  
    /**
     * Método que retorna todos los años activos creados
     * @since   2017-07-15
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   void
     * @return  ListObject SchoolYear
     * 
     */
    public function getAllSchoolYears() {
        return $this
                ->lists('name_scy','serial_scy');                
    }

      /**
     * Método que retorna un año lectivo activo y actual
     * @since   2017-07-15
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   void
     * @return  ListObject SchoolYear
     * 
     */
    public function getCurrentSchoolYear() {
        $query = $this->newQuery();
        $query->where('status_scy','LIKE', 'CURRENT,ACTIVE');
        $query->orWhere('status_scy', "LIKE", "ACTIVE,CURRENT");

        return $this->doQueryFirst($query);
    }
    
    public function getSchoolYearByDate($startDate,$endDate){
        $schoolYear=$this->newQuery();
        $schoolYear->where('start_date_scy','<=',$startDate);
        $schoolYear->where('end_date_scy', '>=', $startDate);
        $schoolYear->where('start_date_scy', '<=', $endDate);
        $schoolYear->where('end_date_scy', '>=', $endDate);
        
        return $this->doQueryFirst($schoolYear);
    }


     /**
     * Método para obtener año lectivo por serial
     * @since   2018-03-15
     * @param serial_scy
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
    public function getSchoolYearBySerialScy($serial_scy) {
        $query = $this->newQuery();
        $query->where('serial_scy', $serial_scy);        

        return $this->doQueryFirst($query);
    }


    /**
     * Método que retorna un años lectivo activo y actual
     * @since   2018-04-04
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   void
     * @return  ListObject SchoolYear
     * 
     */
    public function getSchoolYearsActiveCurrent() {
        $query = $this->newQuery();
        $query->where('status_scy','LIKE', 'CURRENT,ACTIVE');
        $query->orWhere('status_scy', "LIKE", "ACTIVE,CURRENT");

        return $query->pluck('name_scy','serial_scy');   
    }


    /**
     * Método que retorna años lectivos activo y actual con toda su data
     * @since   2018-04-26
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   void
     * @return  ListObject SchoolYear
     * 
     */
    public function getSchoolYearsDataActiveCurrent() {
        $query = $this->newQuery();
        $query->where('status_scy','LIKE', 'CURRENT,ACTIVE');
        $query->orWhere('status_scy', "LIKE", "ACTIVE,CURRENT");

        return $this->doQueryGet($query);
    }

    /**
     * Método para obtener años para admisiones
     * @author Henry Vivanco <hvvivanco@rutatec.com>
     * @since  2019-01-21
     * @return array $states
     */
    public function getSchoolYearForAdmissions() {
        $schoolYear = SchoolYear::where('activities_scy','LIKE','%APPLICATION_FORM%')
            ->pluck('name_scy','serial_scy');
        return $schoolYear;
    }

}
