<?php

namespace App\Repositories;

use App\Models\Skills;
use App\Repositories\BaseRepository;

/**
 * Repostiorio para destrezas
 * @since   2017-07-09
 * @author  Erick Vaca <epvaca@rutatec.com>
 *
 * @edit    2017-07-09<br />
 *          Erick Vaca <epvaca@rutatec.com><br /><br/>
 *          Creación del archivo<br/>
 *          #edit1
 */
class SkillsRepository extends BaseRepository {

    protected $modelClass = Skills::class;

    //Declaración del constructor
    public function __construct(Skills $skills) {
        $this->skills = $skills;
    }

    /**
     * Método que devuelve las destrezas por materia por tipo
     * @since   2017-07-11
     * @author  Erick Vaca <epvaca@rutatec.com>
     * @param   integer $serial_subject serial de la materia
     * @param   string $subject_type atributo para conocer si la materia es obligatoria u optativa
     * @return  object $skills destrezas de la materia
     *
     */
    public function getSkillsAvailableBySubjectType($serial_subject, $subject_type) {
        $query = $this->newQuery();
        $query->where('skills.status_skl', '=','ACTIVE');
        
        if($subject_type == 'MANDATORY'){
            $query->whereNotIn('skills.serial_skl', function($subquery) use($serial_subject){
                $subquery->select('skills.serial_skl')
                ->from('skills')
                ->where('skills.status_skl', '=','ACTIVE')
                ->join('year_subject_skills', function($subquery2) use($serial_subject) {
                    $subquery2->on('skills.serial_skl', '=', 'year_subject_skills.serial_skl')
                            ->where('year_subject_skills.serial_sbc', $serial_subject)
                            ->where('year_subject_skills.status_yss', 'ACTIVE');
                    });
            });
            
        }elseif ($subject_type == 'OPTIONAL') {
            $query->whereNotIn('skills.serial_skl', function($subquery) use($serial_subject){
                $subquery->select('skills.serial_skl')
                ->from('skills')
                ->where('skills.status_skl', '=','ACTIVE')
                ->join('year_subject_skills', function($subquery2) use($serial_subject) {
                    $subquery2->on('skills.serial_skl', '=', 'year_subject_skills.serial_skl')
                            ->where('year_subject_skills.serial_osb', $serial_subject)
                            ->where('year_subject_skills.status_yss', 'ACTIVE');
                    });
            });
        }
        
        $query->select('skills.serial_skl', 'skills.description_skl');
        
        
        return $this->doQueryGet($query);
    }

     /**
     * Método que devuelve las destrezas por materia por tipo
     * @since   2017-07-11
     * @author  Erick Vaca <epvaca@rutatec.com>
     * @param   integer $serial_subject serial de la materia
     * @param   string $subject_type atributo para conocer si la materia es obligatoria u optativa
     * @return  object $skills destrezas de la materia
     *
     */
    public function getSkillsAssignedBySubjectType($serial_subject, $subject_type) {
        $query = $this->newQuery();
        $query->where('skills.status_skl', '=','ACTIVE');
        if($subject_type == 'MANDATORY'){
            $query->join('year_subject_skills', function($join) use($serial_subject) {
            $join->on('skills.serial_skl', '=', 'year_subject_skills.serial_skl')
                    ->where('year_subject_skills.serial_sbc', $serial_subject)
                    ->where('year_subject_skills.status_yss', 'ACTIVE');
            });
        }elseif ($subject_type == 'OPTIONAL') {
            $query->join('year_subject_skills', function($join) use($serial_subject) {
            $join->on('skills.serial_skl', '=', 'year_subject_skills.serial_skl')
                    ->where('year_subject_skills.serial_osb', '=', $serial_subject)
                    ->where('year_subject_skills.status_yss', '=', 'ACTIVE');
            });
        }
        
        $query->select('skills.serial_skl', 'skills.description_skl', 'year_subject_skills.serial_yss', 'year_subject_skills.order_yss');
        $query->orderBy('year_subject_skills.order_yss','ASC');
        
        return $this->doQueryGet($query);
    }

}
