<?php

namespace App\Repositories;

use App\Models\StudentGuardian;
use App\Repositories\BaseRepository;

/**
 * Repostiorio para Student Guardian
 * @since   2018-04-04
 * @author  Erick Vaca <epvaca@rutatec.com>
 *
 * @edit    2018-04-04<br />
 *          Erick Vaca <epvaca@rutatec.com><br /><br/>
 *          Creación del archivo<br/>
 *          #edit1
 */
class StudentGuardianRepository extends BaseRepository {

    protected $modelClass = StudentGuardian::class;

    //Declaración del constructor
    public function __construct(StudentGuardian $studentGuardian) {
        $this->studentGuardian = $studentGuardian;
    }
  
     /**
     * Método que retorna estudiantes de un guardian en un anio
     * @since   2017-07-16
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   void
     * @return  ListObject StudentGuardian
     * 
     */
    public function getStudentsByGuardianInSchoolYear($serial_grd, $serial_scy) {
        $query = $this->newQuery();
        $query->join('student AS std','std.serial_std', '=', 'student_guardian.serial_std');   
        $query->join('student_year AS sy','sy.serial_std', '=', 'student_guardian.serial_std');   
               
        $query->where('student_guardian.status_stg', '=', 'ACTIVE');
        $query->where('std.status_std', '=', 'ACTIVE');
        $query->where('sy.status_sty', '!=', 'RETIRED');       
        $query->where('student_guardian.serial_grd', '=', $serial_grd);
        $query->where('sy.serial_scy', '=', $serial_scy);
        $query->orderBy('std.birthdate_std');
      
        $query->selectRaw("DISTINCT(std.serial_std),
                CONCAT(std.first_name_std, ' ', std.last_name_std) AS name_std");


        return $query->pluck('name_std','serial_std');   
    }

    public function getUserGuardian($serial_std,$status_usr){
        $query = $this->newQuery();
        $query->join('guardian AS grd','student_guardian.serial_grd', '=', 'grd.serial_grd');
        $query->join('user AS usr','grd.serial_usr', '=', 'usr.serial_usr');
        $query->where('student_guardian.status_stg', '=', 'ACTIVE');
        $query->where('student_guardian.serial_std', '=', $serial_std);
        $query->where('usr.status_usr', '=', $status_usr);

        return $this->doQueryGet($query);
    }

}
