<?php

namespace App\Repositories;

use App\Models\StudentOptionalSubject;
use App\Repositories\BaseRepository;

/**
 * Repositorio del usuario

 * @author Erick Vaca <epvaca@rutatec.com>
 * @since  2018-04-05
 */
class StudentOptionalSubjectRepository extends BaseRepository {

    protected $modelClass = StudentOptionalSubject::class;

    protected $studentOptionalSubject;


    public function __construct(StudentOptionalSubject $studentOptionalSubject) {
        $this->studentOptionalSubject = $studentOptionalSubject;
    }

    public function getOptionalSubjectsByStudent($serial_scy, $serial_prd, $serial_std) {
        
        $optionalSubjects = $this->newQuery();
        $optionalSubjects->join('level_optional_group', 'level_optional_group.serial_lop', '=', 'student_optional_subject.serial_lop');
        $optionalSubjects->join('school_year', 'school_year.serial_scy', '=', 'level_optional_group.serial_scy');
        $optionalSubjects->join('period_group_year', 'period_group_year.serial_scy', '=', 'school_year.serial_scy');
        $optionalSubjects->join('period', 'period.serial_pgy', '=', 'period_group_year.serial_pgy');
        $optionalSubjects->join('optional_subject', 'optional_subject.serial_osb', '=', 'student_optional_subject.serial_osb');
        $optionalSubjects->join('optional_subject_level', 'optional_subject_level.serial_osb', '=', 'optional_subject.serial_osb');
        $optionalSubjects->leftJoin('subject_category','subject_category.serial_scat','=','optional_subject_level.serial_scat');
        $optionalSubjects->where('student_optional_subject.serial_std', '=', $serial_std);
        $optionalSubjects->where('period.serial_prd', '=', $serial_prd);
        $optionalSubjects->where('period_group_year.serial_scy', '=', $serial_scy);
        $optionalSubjects->where('optional_subject_level.has_grades', '=', 1);
        $optionalSubjects->where('status_sos', '=', 'ACTIVE');
        $optionalSubjects->where('status_lop', '=', 'ACTIVE');
        $optionalSubjects->where('status_pgy', '=', 'ACTIVE');
        $optionalSubjects->where('status_prd', '=', 'ACTIVE');
        $optionalSubjects->where('status_osb', '=', 'ACTIVE');
        $optionalSubjects->selectRaw('distinct level_optional_group.name_lop,"N/A" as cat_name,"N/A" as cat_serial_csb,
                    level_optional_group.serial_lop,"N/A" as serial_sbc,level_optional_group.order_lop as orden,
                    optional_subject.grade_type_sbc as grade_type_sbc');
        return $this->doQueryGet($optionalSubjects);
    }


    public function checkLevelOptionalGroupByStudent($serial_std,$serial_lop){
        $studentOptionalSubjects = $this->newQuery();
        $studentOptionalSubjects->join('level_optional_group as lop', function($join){
            $join->on('lop.serial_lop','student_optional_subject.serial_lop')
                ->where('lop.status_lop','=','ACTIVE');
        })->where('serial_std',$serial_std)
            ->where('lop.serial_lop',$serial_lop)
            ->where('student_optional_subject.status_sos','=','ACTIVE');
        $result=$this->doQueryFirst($studentOptionalSubjects);

        if($result){
            return $result;
        }else{
            return false;
        }

    }

}
