<?php

namespace App\Repositories;

use App\Models\SubjectCourse;
use App\Repositories\BaseRepository;

/**
 * Repostiorio para materias obligatorias
 * @since   2017-07-09
 * @author  Erick Vaca <epvaca@rutatec.com>
 *
 * @edit    2017-07-09<br />
 *          Erick Vaca <epvaca@rutatec.com><br /><br/>
 *          Creación del archivo<br/>
 *          #edit1
 */
class SubjectCourseRepository extends BaseRepository {

    protected $modelClass = SubjectCourse::class;

    //Declaración del constructor
    public function __construct(SubjectCourse $subjectCourse) {
        $this->subjectCourse = $subjectCourse;
    }
  
     /**
     * Método que retorna materias con serial concatenado de serial_sbc por seccion, nivel , especialidad, anio lectivo
     * @since   2017-07-16
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   void
     * @return  ListObject SubjectCourse
     * 
     */
    public function getSubjectsBySchoolYearSectionLevel($serial_scy, $serial_set, $serial_lvl, $serial_spt) {
        $query = $this->newQuery();
        $query->join('subject AS sbj','subject_course.serial_sbj', '=', 'sbj.serial_sbj');
        $query->join('cat_subject AS csb','csb.serial_csb', '=', 'sbj.serial_csb');
        $query->leftJoin('cat_subject as cs2', function($join) {
           $join->on('cs2.serial_csb', '=', 'csb.cat_serial_csb');                   
           });
        $query->join('course AS crs', 'crs.serial_crs', '=', 'subject_course.serial_crs');
        $query->join('level AS lvl', 'lvl.serial_lvl', '=', 'crs.serial_lvl');
        $query->join('class_group AS clg', 'clg.serial_clg', '=', 'crs.serial_clg');
        $query->join('level_section_year AS lsy', function($join){
             $join->on('lsy.serial_lvl', '=', 'lvl.serial_lvl')
            ->on('lsy.serial_set', '=', 'crs.serial_set')
            ->on('lsy.serial_scy', '=', 'crs.serial_scy'); 
        });
        
        $query->where('subject_course.status_sbc', '=', 'ACTIVE');
        $query->where('sbj.status_sbj', '=', 'ACTIVE');
        $query->where('csb.status_csb', '=', 'ACTIVE');
        $query->where('crs.serial_scy', '=', $serial_scy);
        $query->where('crs.serial_set', '=', $serial_set);
        $query->where('crs.serial_lvl', '=', $serial_lvl);
        $query->where('crs.serial_spt', '=', $serial_spt);
        $query->groupBy('csb.serial_csb');
        $query->selectRaw("GROUP_CONCAT(DISTINCT(subject_course.serial_sbc)) as serial,IFNULL(CONCAT(cs2.name_csb,' - ',csb.name_csb),csb.name_csb) as name_csb,      
                    csb.code_csb, lsy.order_lsy as orden, csb.serial_csb");


        return $this->doQueryGet($query);

    }

         /**
     * Método que retorna informacion de materia
     * @since   2018-03-19
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   void
     * @return  ListObject SubjectCourse
     * 
     */
    public function getSubjectCourseInformation($serial_sbc) {
        $query = $this->newQuery();
        $query->join('course AS crs', 'crs.serial_crs', '=', 'subject_course.serial_crs');
                
        $query->where('subject_course.status_sbc', '=', 'ACTIVE');        
        $query->where('crs.status_crs', '=', 'ACTIVE');
        $query->where('subject_course.serial_sbc', '=', $serial_sbc);
  
        return $this->doQueryGet($query)->toArray();

    }


     /**
     * Método que devuelve la materia, su sección,nivel y paralelo
     * @since   2018-03-22
     * @author  Erick Vaca <epvaca@rutatec.com> 
     * @param   integer  $serial_sbc serial de la materia
     * @param   integer  $serial_scy serial del año lectivo
     * @return  object materia
     *
     */
    public function getSubjectCourseBySerialSbcSchoolYear($serial_sbc,$serial_scy) {

        $query = $this->newQuery();

        $query->join('subject as sbj', 'subject_course.serial_sbj', '=', 'sbj.serial_sbj');
        $query->join('cat_subject as csb', 'csb.serial_csb', '=', 'sbj.serial_csb');
        $query->leftJoin('cat_subject as cs2', 'cs2.serial_csb', '=', 'csb.cat_serial_csb');
        $query->join('section as set', 'sbj.serial_set', '=', 'set.serial_set');
        $query->join('school_year as scy', 'scy.serial_scy', '=', 'sbj.serial_scy');
        $query->join('course as crs', 'crs.serial_crs', '=', 'subject_course.serial_crs');
        $query->join('level as lvl', 'crs.serial_lvl', '=', 'lvl.serial_lvl');
        $query->join('class_group as clg', 'clg.serial_clg', '=', 'crs.serial_clg');
        $query->join('level_section_year as lsy', function($join) {
            $join->on('lvl.serial_lvl', '=', 'lsy.serial_lvl')
            ->on('lsy.serial_set', '=', 'crs.serial_set')
            ->on('lsy.serial_scy', '=', 'scy.serial_scy');
        });
        $query->where('sbj.status_sbj', 'ACTIVE');
        $query->where('csb.status_csb', 'ACTIVE');
        $query->where('set.status_set', 'ACTIVE');
        $query->where('crs.status_crs', 'ACTIVE');
        $query->where('lvl.status_lvl', 'ACTIVE');
        $query->where('clg.status_clg', 'ACTIVE');
        $query->where('lsy.status_lsy', 'ACTIVE');
        $query->where('subject_course.serial_sbc', $serial_sbc);
        $query->where('sbj.serial_scy', $serial_scy);
        $query->selectRaw("scy.name_scy,set.name_set,concat(lvl.name_lvl,' ',clg.name_clg) as course,subject_course.serial_sbc,lsy.serial_pgy, IFNULL(CONCAT(cs2.name_csb,' - ',csb.name_csb),csb.name_csb) as name_csb,crs.serial_crs,scy.setup_skills");
        return $this->doQueryFirst($query);
    }

    public function getSubjectCourse($serial_sbc)
    {
        $subject = $this->newQuery();
        $subject->join('subject as sbj', function ($join) {
            $join->on('sbj.serial_sbj', '=', 'subject_course.serial_sbj')
                ->where('status_sbj', '=', 'ACTIVE');
        });
        $subject->join('cat_subject as csb', function ($join) {
            $join->on('csb.serial_csb', '=', 'sbj.serial_csb')
                ->where('status_csb', '=', 'ACTIVE');
        });
        $subject->where('serial_sbc', '=', $serial_sbc);
        $subject->where('status_sbc', '=', 'ACTIVE');
        $subject->selectRaw('serial_sbc as serial,IF(csb.short_name_csb is null,csb.name_csb,csb.short_name_csb) as "name_subject",grade_type_sbc as "grade_type"');
        return $this->doQueryFirst($subject);

    }

}
