<?php

namespace App\Repositories;

use App\Models\SubjectPlanningUnit;


class SubjectPlanningUnitRepository extends BaseRepository {

    protected $modelClass = SubjectPlanningUnit::class;

    protected $subjectPlanningUnit;


    public function __construct(SubjectPlanningUnit $subjectPlanningUnit) {
        $this->subjectPlanningUnit = $subjectPlanningUnit;
    }


    public function setPlanningUnitToSubjectYearPlanning($data) {
        //check if exist
        $result= $this->subjectPlanningUnit->where('serial_syp','=',$data['serial_syp'])
            ->where('serial_lpu','=',$data['serial_lpu'])
            ->first();
        if(!$result){
            $subjectPlanningUnit = new SubjectPlanningUnit();
            $subjectPlanningUnit->serial_syp=$data['serial_syp'];
            $subjectPlanningUnit->serial_lpu=$data['serial_lpu'];
            $subjectPlanningUnit->save();
            return $subjectPlanningUnit;

        }else{
            $result->status_spu=$data['status_spu'];
            $result->save();
            return $result;
        }
        return false;

    }

    public function setDatesPlanningUnit($data){
        //check if exist
        $result= $this->subjectPlanningUnit->where('serial_spu','=',$data['serial_spu'])
            ->where('status_spu','=','ACTIVE')
            ->first();

        if($result){
            $result->start_date_spu=$data['start_date_spu'];
            $result->end_date_spu=$data['end_date_spu'];
            $result->save();
            return $result;
        }
        return false;
    }


    public function getSubjectPlanningUnit($serial_spu) {
        $subjectPlanningUnit = SubjectPlanningUnit::where('serial_spu', '=', $serial_spu)
            ->where('status_spu', '=', 'ACTIVE')
            ->first();
        return $subjectPlanningUnit;
    }
    public function getSubjectPlanningUnitDetail($serial_spu) {
        $subjectPlanningUnit = SubjectPlanningUnit::where('serial_spu', '=', $serial_spu)
            ->where('status_spu', '=', 'ACTIVE')
            ->first();
        return $subjectPlanningUnit;
    }

    public function getLevelObjectivesUnit($serial_spu){
        $subjectPlanningUnit = SubjectPlanningUnit::where('serial_spu', '=', $serial_spu)
            ->where('status_spu', '=', 'ACTIVE')
            ->first();
        $subjectObjectivesUnit=$subjectPlanningUnit->levelObjectivesUnit()->with('specificObjectivesUnit')
            ->where('status_sot', '=', 'ACTIVE')
            ->get();
        $result=array();
        foreach ($subjectObjectivesUnit as $key=>$subjectObjectiveUnit){
            $result[$key]['serial_lou']=$subjectObjectiveUnit->serial_lou;
            $result[$key]['description_sou']=$subjectObjectiveUnit->specificObjectivesUnit->description_sou;
            $result[$key]['is_ministry_sou']=$subjectObjectiveUnit->specificObjectivesUnit->is_ministry_sou;
        }
        return $result;
    }
    public function getLevelUnitSkill($serial_spu){
        $subjectPlanningUnit = SubjectPlanningUnit::where('serial_spu', '=', $serial_spu)
            ->where('status_spu', '=', 'ACTIVE')
            ->first();
        $subjectSkillsUnit=$subjectPlanningUnit->levelUnitSkill()->with('planningUnitSkills')
            ->where('status_sus', '=', 'ACTIVE')
            ->get();
        $result=array();
        foreach ($subjectSkillsUnit as $key=>$subjectSkillUnit){
            $result[$key]['serial_lus']=$subjectSkillUnit->serial_lus;
            $result[$key]['description_pus']=$subjectSkillUnit->planningUnitSkills->description_pus;
            $result[$key]['is_ministry_pus']=$subjectSkillUnit->planningUnitSkills->is_ministry_pus;
        }
        return $result;
    }
    public function getLevelMethodologicalOrientation($serial_spu){
        $subjectPlanningUnit = SubjectPlanningUnit::where('serial_spu', '=', $serial_spu)
            ->where('status_spu', '=', 'ACTIVE')
            ->first();
        $subjectMethodologicalOrientations=$subjectPlanningUnit->levelMethodologicalOrientationUnit()->with('methodologicalOrientationUnit')
            ->where('status_smo', '=', 'ACTIVE')
            ->get();
        $result=array();
        foreach ($subjectMethodologicalOrientations as $key=>$subjectMethodologicalOrientation){
            $result[$key]['serial_lmo']=$subjectMethodologicalOrientation->serial_lmo;
            $result[$key]['description_mou']=$subjectMethodologicalOrientation->methodologicalOrientationUnit->description_mou;
            $result[$key]['is_ministry_mou']=$subjectMethodologicalOrientation->methodologicalOrientationUnit->is_ministry_mou;
        }
        return $result;
    }

    public function getLevelEvaluationIndicators($serial_spu){
        $subjectPlanningUnit = SubjectPlanningUnit::where('serial_spu', '=', $serial_spu)
            ->where('status_spu', '=', 'ACTIVE')
            ->first();
        $subjectEvaluationIndicators=$subjectPlanningUnit->levelEvaluationIndicators()->with('evaluationIndicatorsUnit')
            ->where('status_sei', '=', 'ACTIVE')
            ->get();
        $result=array();
        foreach ($subjectEvaluationIndicators as $key=>$subjectEvaluationIndicator){
            $result[$key]['serial_lei']=$subjectEvaluationIndicator->serial_lei;
            $result[$key]['description_eiu']=$subjectEvaluationIndicator->evaluationIndicatorsUnit->description_eiu;
            $result[$key]['is_ministry_eiu']=$subjectEvaluationIndicator->evaluationIndicatorsUnit->is_ministry_eiu;
        }
        return $result;
    }

    public function getLevelTransverseUnit($serial_spu){
        $subjectPlanningUnit = SubjectPlanningUnit::where('serial_spu', '=', $serial_spu)
            ->where('status_spu', '=', 'ACTIVE')
            ->first();
        $subjectTransverseUnits=$subjectPlanningUnit->levelTransverseUnit()->with('transverseAxisUnit')
            ->where('status_stu', '=', 'ACTIVE')
            ->get();
        $result=array();
        foreach ($subjectTransverseUnits as $key=>$subjectTransverseUnit){
            $result[$key]['serial_ltu']=$subjectTransverseUnit->serial_ltu;
            $result[$key]['description_txu']=$subjectTransverseUnit->transverseAxisUnit->description_txu;
            $result[$key]['is_ministry_txu']=$subjectTransverseUnit->transverseAxisUnit->is_ministry_txu;
        }
        return $result;
    }

    public function getLevelStrategiesUnit($serial_spu){
        $subjectPlanningUnit = SubjectPlanningUnit::where('serial_spu', '=', $serial_spu)
            ->where('status_spu', '=', 'ACTIVE')
            ->first();
        $subjectStrategiesUnit=$subjectPlanningUnit->levelStrategiesUnit()->with('methodologicalStrategiesUnit')
            ->where('status_ssu', '=', 'ACTIVE')
            ->get();
        $result=array();
        foreach ($subjectStrategiesUnit as $key=>$subjectStrategyUnit){
            $result[$key]['serial_lsu']=$subjectStrategyUnit->serial_lsu;
            $result[$key]['description_msu']=$subjectStrategyUnit->methodologicalStrategiesUnit->description_msu;
            $result[$key]['is_ministry_msu']=$subjectStrategyUnit->methodologicalStrategiesUnit->is_ministry_msu;
        }
        return $result;
    }

    public function getLevelResourcesUnit($serial_spu){
        $subjectPlanningUnit = SubjectPlanningUnit::where('serial_spu', '=', $serial_spu)
            ->where('status_spu', '=', 'ACTIVE')
            ->first();
        $subjectResourcesUnit=$subjectPlanningUnit->levelResourcesUnit()->with('resourcesPlanningUnit')
            ->where('status_sru', '=', 'ACTIVE')
            ->get();
        $result=array();
        foreach ($subjectResourcesUnit as $key=>$subjectResourceUnit){
            $result[$key]['serial_lru']=$subjectResourceUnit->serial_lru;
            $result[$key]['description_rpu']=$subjectResourceUnit->resourcesPlanningUnit->description_rpu;
            $result[$key]['is_ministry_rpu']=$subjectResourceUnit->resourcesPlanningUnit->is_ministry_rpu;
        }
        return $result;
    }

    public function getLevelIndicatorsUnit($serial_spu){
        $subjectPlanningUnit = SubjectPlanningUnit::where('serial_spu', '=', $serial_spu)
            ->where('status_spu', '=', 'ACTIVE')
            ->first();
        $subjectIndicatorsUnit=$subjectPlanningUnit->levelIndicatorsUnit()->with('achievementIndicatorsUnit')
            ->where('status_siu', '=', 'ACTIVE')
            ->get();
        $result=array();
        foreach ($subjectIndicatorsUnit as $key=>$subjectIndicatorUnit){
            $result[$key]['serial_liu']=$subjectIndicatorUnit->serial_liu;
            $result[$key]['description_aiu']=$subjectIndicatorUnit->achievementIndicatorsUnit->description_aiu;
            $result[$key]['is_ministry_aiu']=$subjectIndicatorUnit->achievementIndicatorsUnit->is_ministry_aiu;
        }
        return $result;
    }




}
