<?php

namespace App\Repositories;

use App\Models\LevelPlanningForm;
use App\Models\SubjectGroupPlanning;
use App\Models\SubjectYearPlanning;
use App\Repositories\BaseRepository;


class SubjectYearPlanningRepository extends BaseRepository {

    protected $modelClass = SubjectYearPlanning::class;

    protected $subjectYearPlanning;


    public function __construct(SubjectYearPlanning $subjectYearPlanning) {
        $this->subjectYearPlanning = $subjectYearPlanning;
    }

    public function saveSubjectYearPlanning($data) {

        //busca si existe el registro lo actualiza
        if(isset($data['serial_syp'])){
            $subjectYearPlanning = $this->getSubjectYearPlanning($data['serial_syp']);
        }else{
            $subjectYearPlanning=null;
        }

        if ($subjectYearPlanning != null) {
                $subjectYearPlanning->name_syp = $data['name_syp'];
                $subjectYearPlanning->description_syp = $data['description_syp'];
                $subjectYearPlanning->workload_syp = $data['workload_syp'];
                $subjectYearPlanning->weeks_number_syp = $data['weeks_number_syp'];
                $subjectYearPlanning->unforeseen_syp = $data['unforeseen_syp'];
                $subjectYearPlanning->total_weekly_classes_syp = $data['total_weekly_classes_syp'];
                $subjectYearPlanning->total_periods_syp = $data['total_periods_syp'];
                $subjectYearPlanning->status_syp = isset($data['status_syp'])?$data['status_syp']:'ACTIVE';
                $subjectYearPlanning->save();
        } else {
            //Crea nuevo registro
            $subjectYearPlanning = new SubjectYearPlanning();
            $subjectYearPlanning->name_syp = $data['name_syp'];
            $subjectYearPlanning->description_syp = $data['description_syp'];
            $subjectYearPlanning->workload_syp = $data['workload_syp'];
            $subjectYearPlanning->weeks_number_syp = $data['weeks_number_syp'];
            $subjectYearPlanning->unforeseen_syp = $data['unforeseen_syp'];
            $subjectYearPlanning->total_weekly_classes_syp = $data['total_weekly_classes_syp'];
            $subjectYearPlanning->total_periods_syp = $data['total_periods_syp'];
            $subjectYearPlanning->save();

            //guardar en grupo
            $subjectGroupPlanning = SubjectGroupPlanning::where('serial_sgp', '=', $data['serial_sgp'])->first();
            //obtengo todas las materias del grupo
            $subjectGroupPlanningArray = SubjectGroupPlanning::where('number_group_sgp', '=', $subjectGroupPlanning->number_group_sgp)->get();
            foreach ($subjectGroupPlanningArray as $subject) {
                $subject->serial_syp=$subjectYearPlanning->serial_syp;
                $subject->save();
            }
        }
        return $subjectYearPlanning;
    }


    public function getSubjectYearPlanning($serial_syp) {
        $subjectYearPlanning = SubjectYearPlanning::where('serial_syp', '=', $serial_syp)
            ->where('status_syp', '=', 'ACTIVE')
            ->first();
        return $subjectYearPlanning;
    }

    public function getLevelGeneralObjectives($serial_syp){
        $subjectYearPlanning = SubjectYearPlanning::where('serial_syp', '=', $serial_syp)
            ->where('status_syp', '=', 'ACTIVE')
            ->first();
        $subjectGeneralObjectives=$subjectYearPlanning->levelGeneralObjectives()->with('generalAreaObjectives')->where('status_sgo','ACTIVE')->get();
        $result=array();
        foreach ($subjectGeneralObjectives as $key=>$subjectGeneralObjective){
            $result[$key]['serial_lgo']=$subjectGeneralObjective->serial_lgo;
            $result[$key]['description_gao']=$subjectGeneralObjective->generalAreaObjectives->description_gao;
            $result[$key]['is_ministry_objective']=$subjectGeneralObjective->generalAreaObjectives->is_ministry_objective;
        }
        usort($result, function($a, $b)
        {
            return strcmp($a['description_gao'], $b['description_gao']);
        });
        return $result;
    }

    public function getLevelSpecificObjectives($serial_syp){
        $subjectYearPlanning = SubjectYearPlanning::where('serial_syp', '=', $serial_syp)
            ->where('status_syp', '=', 'ACTIVE')
            ->first();
        $subjectSpecificObjectives=$subjectYearPlanning->levelSpecificObjectives()->with('specificObjectives')->where('status_sso','ACTIVE')->get();
        $result=array();
        foreach ($subjectSpecificObjectives as $key=>$subjectSpecificObjective){
            $result[$key]['serial_lso']=$subjectSpecificObjective->serial_lso;
            $result[$key]['description_pso']=$subjectSpecificObjective->specificObjectives->description_pso;
            $result[$key]['is_ministry_objective']=$subjectSpecificObjective->specificObjectives->is_ministry_objective;
        }
        usort($result, function($a, $b)
        {
            return strcmp($a['description_pso'], $b['description_pso']);
        });
        return $result;
    }
    public function getLevelTransverseAxis($serial_syp){
        $subjectYearPlanning = SubjectYearPlanning::where('serial_syp', '=', $serial_syp)
            ->where('status_syp', '=', 'ACTIVE')
            ->first();
        $subjectTransverseAxes=$subjectYearPlanning->levelTransverseAxis()->with('transverseAxis')->where('status_trx','ACTIVE')->get();
        $result=array();
        foreach ($subjectTransverseAxes as $key=>$subjectTransverseAxis){
            $result[$key]['serial_ltx']=$subjectTransverseAxis->serial_ltx;
            $result[$key]['description_ptx']=$subjectTransverseAxis->transverseAxis->description_ptx;
            $result[$key]['is_ministry_ptx']=$subjectTransverseAxis->transverseAxis->is_ministry_ptx;
        }
        usort($result, function($a, $b)
        {
            return strcmp($a['description_ptx'], $b['description_ptx']);
        });
        return $result;
    }

    public function getLevelPlanningUnits($serial_syp){
        $subjectYearPlanning = SubjectYearPlanning::where('serial_syp', '=', $serial_syp)
            ->where('status_syp', '=', 'ACTIVE')
            ->first();
        $subjectPlanningUnits=$subjectYearPlanning->levelPlanningUnit()->with('planningUnit')->with('subjectPlanningUnit')->where('status_spu','ACTIVE')->get();
        $result=array();
        foreach ($subjectPlanningUnits as $key=>$subjectPlanningUnit){
            $result[$key]['serial_lpu']=$subjectPlanningUnit->serial_lpu;
            $result[$key]['serial_spu']=$subjectPlanningUnit->subjectPlanningUnit->serial_spu;
            $result[$key]['serial_put']=$subjectPlanningUnit->planningUnit->serial_put;
            $result[$key]['description_put']=$subjectPlanningUnit->planningUnit->description_put;
            $result[$key]['is_ministry_put']=$subjectPlanningUnit->planningUnit->is_ministry_put;
        }
        usort($result, function($a, $b)
        {
            return strcmp($a['description_put'], $b['description_put']);
        });
        return $result;
    }

    public function getLevelPlanningForm($serial_syp){
        $subjectGroupPlanning = SubjectGroupPlanning::where('serial_syp', '=', $serial_syp)
            ->where('status_sgp', '=', 'ACTIVE')
            ->first();
        $levelPlanningForm= LevelPlanningForm::where('serial_lvl','=',$subjectGroupPlanning->serial_lvl)
            ->where('serial_set','=',$subjectGroupPlanning->serial_set)
            ->with('planningForm')
            ->first();
        if($levelPlanningForm){
            return $levelPlanningForm;
        }else{
            return null;
        }
    }


}
