<?php

namespace App\Repositories;

use App\Models\Subperiod;

class SubperiodRepository extends BaseRepository {

    protected $modelClass = Subperiod::class;
    protected $subperiod;

    //Declaración del constructor
    public function __construct(Subperiod $subperiod) {
        $this->subperiod = $subperiod;
    }


    /**
     * Método para obtener datos de subperiodo por serial
     * @since   2018-03-28
     * @param   integer serial_sbp serial subperiodo
     * @author   Erick Vaca <epvaca@rutatec.com><br /><br/>
     * @return  json resultado
     *
     */
   public function getSubperiodDataBySerialSbp($serial_sbp) {

        $query = $this->newQuery();
        $query->join('period as prd', 'prd.serial_prd', '=', 'subperiod.serial_prd');

        $query->where('subperiod.serial_sbp', '=', $serial_sbp);
        $query->where('prd.status_prd', '=', 'ACTIVE');
        $query->where('subperiod.status_sbp', '=', 'ACTIVE');

        return $this->doQueryFirst($query);
    }
    /**
     * Método para obtener datos de subperiodo por serial del periodo
     * @since   2018-03-28
     * @param   integer serial_sbp serial subperiodo
     * @author  Fernando Salas <rfsalas@rutatec.com><br /><br/>
     * @return  json $subperiods subperiodos activos del parcial
     *
     */
    public function getSubperiodsByPeriod($serial_prd) {
        $subperiods = $this->newQuery();
        $subperiods->where('serial_prd', '=', $serial_prd);
        $subperiods->where('status_sbp', '=', 'ACTIVE');
        $subperiods->select('serial_sbp', 'name_sbp');
        return $this->doQueryGet($subperiods);
    }

}
