<?php

namespace App\Repositories;

use App\Models\YearSubjectSkills;
use App\Repositories\BaseRepository;

/**
 * Repostiorio para configuracion de destrezas
 * @since   2017-07-09
 * @author  Erick Vaca <epvaca@rutatec.com>
 *
 * @edit    2017-07-09<br />
 *          Erick Vaca <epvaca@rutatec.com><br /><br/>
 *          Creación del archivo<br/>
 *          #edit1
 */
class YearSubjectSkillsRepository extends BaseRepository {

    protected $modelClass = YearSubjectSkills::class;

    //Declaración del constructor
    public function __construct(YearSubjectSkills $yearSubjectSkills) {
        $this->yearSubjectSkills = $yearSubjectSkills;
    }
  

     /**
     * Método para actualizar destreza por materia
     * @since   2017-07-19
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   void
     * @return  ListObject YearSubjectSkills
     * 
     */
    public function updateYearSubjectSkillsBySubjectTypeSkill($subject_type,$serial_skl,$serial_subjects,$update_data) {
        $serialSubjectsArray = explode(',', $serial_subjects);    

        $query = $this->newQuery();
        if($subject_type == 'MANDATORY'){
            $query->where('serial_skl', $serial_skl)->whereIn('serial_sbc', $serialSubjectsArray)->update($update_data);
        }elseif ($subject_type == 'OPTIONAL') {
            $query->where('serial_skl', $serial_skl)->whereIn('serial_osb', $serialSubjectsArray)->update($update_data);
        }

        return response()->json('OK');
    }

    /**
     * Método para obtener registro existente por skill y materia
     * @since   2017-07-20
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   void
     * @return  ListObject YearSubjectSkills
     * 
     */
    public function getYearSubjectSkillBySubjectTypeSkill($subject_type,$serial_skl,$serial_subject) {

        $query = $this->newQuery();
        if($subject_type == 'MANDATORY'){
            $query->where('serial_skl', $serial_skl)->where('serial_sbc', $serial_subject);
        }elseif ($subject_type == 'OPTIONAL') {
            $query->where('serial_skl', $serial_skl)->where('serial_osb', $serial_subject);
        }

         return $this->doQueryFirst($query);
    }

    /**
     * Método que inserta nuevo registro
     * @since   2017-07-20
     * @author  Erick Vaca <epvaca@rutatec.com> 
     *
     * @param   void
     * @return  ListObject YearSubjectSkills
     * 
     */
    public function insertYearSubjectSkillsBySubjectTypeSkill($subject_type,$serial_skl,$serial_subject,$order) {

        $newRecord = new YearSubjectSkills;

        $newRecord->serial_skl = $serial_skl;
        if($subject_type == 'MANDATORY'){
            $newRecord->serial_sbc = $serial_subject;
       }elseif ($subject_type == 'OPTIONAL') {
            $newRecord->serial_osb = $serial_subject;
       }
       if($order){
            $newRecord->order_yss = $order;
       }
        $newRecord->status_yss = 'ACTIVE';

        $newRecord = $newRecord->save();

        return response()->json($newRecord);
    }

}
